# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: exchange/injective_derivative_exchange_rpc.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='exchange/injective_derivative_exchange_rpc.proto',
  package='injective_derivative_exchange_rpc',
  syntax='proto3',
  serialized_options=b'Z$/injective_derivative_exchange_rpcpb',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n0exchange/injective_derivative_exchange_rpc.proto\x12!injective_derivative_exchange_rpc\"<\n\x0eMarketsRequest\x12\x15\n\rmarket_status\x18\x01 \x01(\t\x12\x13\n\x0bquote_denom\x18\x02 \x01(\t\"[\n\x0fMarketsResponse\x12H\n\x07markets\x18\x01 \x03(\x0b\x32\x37.injective_derivative_exchange_rpc.DerivativeMarketInfo\"\xff\x05\n\x14\x44\x65rivativeMarketInfo\x12\x11\n\tmarket_id\x18\x01 \x01(\t\x12\x15\n\rmarket_status\x18\x02 \x01(\t\x12\x0e\n\x06ticker\x18\x03 \x01(\t\x12\x13\n\x0boracle_base\x18\x04 \x01(\t\x12\x14\n\x0coracle_quote\x18\x05 \x01(\t\x12\x13\n\x0boracle_type\x18\x06 \x01(\t\x12\x1b\n\x13oracle_scale_factor\x18\x07 \x01(\r\x12\x1c\n\x14initial_margin_ratio\x18\x08 \x01(\t\x12 \n\x18maintenance_margin_ratio\x18\t \x01(\t\x12\x13\n\x0bquote_denom\x18\n \x01(\t\x12\x46\n\x10quote_token_meta\x18\x0b \x01(\x0b\x32,.injective_derivative_exchange_rpc.TokenMeta\x12\x16\n\x0emaker_fee_rate\x18\x0c \x01(\t\x12\x16\n\x0etaker_fee_rate\x18\r \x01(\t\x12\x1c\n\x14service_provider_fee\x18\x0e \x01(\t\x12\x14\n\x0cis_perpetual\x18\x0f \x01(\x08\x12\x1b\n\x13min_price_tick_size\x18\x10 \x01(\t\x12\x1e\n\x16min_quantity_tick_size\x18\x11 \x01(\t\x12U\n\x15perpetual_market_info\x18\x12 \x01(\x0b\x32\x36.injective_derivative_exchange_rpc.PerpetualMarketInfo\x12[\n\x18perpetual_market_funding\x18\x13 \x01(\x0b\x32\x39.injective_derivative_exchange_rpc.PerpetualMarketFunding\x12^\n\x1a\x65xpiry_futures_market_info\x18\x14 \x01(\x0b\x32:.injective_derivative_exchange_rpc.ExpiryFuturesMarketInfo\"n\n\tTokenMeta\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07\x61\x64\x64ress\x18\x02 \x01(\t\x12\x0e\n\x06symbol\x18\x03 \x01(\t\x12\x0c\n\x04logo\x18\x04 \x01(\t\x12\x10\n\x08\x64\x65\x63imals\x18\x05 \x01(\x11\x12\x12\n\nupdated_at\x18\x06 \x01(\x12\"\x8e\x01\n\x13PerpetualMarketInfo\x12\x1f\n\x17hourly_funding_rate_cap\x18\x01 \x01(\t\x12\x1c\n\x14hourly_interest_rate\x18\x02 \x01(\t\x12\x1e\n\x16next_funding_timestamp\x18\x03 \x01(\x12\x12\x18\n\x10\x66unding_interval\x18\x04 \x01(\x12\"f\n\x16PerpetualMarketFunding\x12\x1a\n\x12\x63umulative_funding\x18\x01 \x01(\t\x12\x18\n\x10\x63umulative_price\x18\x02 \x01(\t\x12\x16\n\x0elast_timestamp\x18\x03 \x01(\x12\"Q\n\x17\x45xpiryFuturesMarketInfo\x12\x1c\n\x14\x65xpiration_timestamp\x18\x01 \x01(\x12\x12\x18\n\x10settlement_price\x18\x02 \x01(\t\"\"\n\rMarketRequest\x12\x11\n\tmarket_id\x18\x01 \x01(\t\"Y\n\x0eMarketResponse\x12G\n\x06market\x18\x01 \x01(\x0b\x32\x37.injective_derivative_exchange_rpc.DerivativeMarketInfo\")\n\x13StreamMarketRequest\x12\x12\n\nmarket_ids\x18\x01 \x03(\t\"\x8a\x01\n\x14StreamMarketResponse\x12G\n\x06market\x18\x01 \x01(\x0b\x32\x37.injective_derivative_exchange_rpc.DerivativeMarketInfo\x12\x16\n\x0eoperation_type\x18\x02 \x01(\t\x12\x11\n\ttimestamp\x18\x03 \x01(\x12\"I\n\x1b\x42inaryOptionsMarketsRequest\x12\x15\n\rmarket_status\x18\x01 \x01(\t\x12\x13\n\x0bquote_denom\x18\x02 \x01(\t\"k\n\x1c\x42inaryOptionsMarketsResponse\x12K\n\x07markets\x18\x01 \x03(\x0b\x32:.injective_derivative_exchange_rpc.BinaryOptionsMarketInfo\"\xf3\x03\n\x17\x42inaryOptionsMarketInfo\x12\x11\n\tmarket_id\x18\x01 \x01(\t\x12\x15\n\rmarket_status\x18\x02 \x01(\t\x12\x0e\n\x06ticker\x18\x03 \x01(\t\x12\x15\n\roracle_symbol\x18\x04 \x01(\t\x12\x17\n\x0foracle_provider\x18\x05 \x01(\t\x12\x13\n\x0boracle_type\x18\x06 \x01(\t\x12\x1b\n\x13oracle_scale_factor\x18\x07 \x01(\r\x12\x1c\n\x14\x65xpiration_timestamp\x18\x08 \x01(\x12\x12\x1c\n\x14settlement_timestamp\x18\t \x01(\x12\x12\x13\n\x0bquote_denom\x18\n \x01(\t\x12\x46\n\x10quote_token_meta\x18\x0b \x01(\x0b\x32,.injective_derivative_exchange_rpc.TokenMeta\x12\x16\n\x0emaker_fee_rate\x18\x0c \x01(\t\x12\x16\n\x0etaker_fee_rate\x18\r \x01(\t\x12\x1c\n\x14service_provider_fee\x18\x0e \x01(\t\x12\x1b\n\x13min_price_tick_size\x18\x0f \x01(\t\x12\x1e\n\x16min_quantity_tick_size\x18\x10 \x01(\t\x12\x18\n\x10settlement_price\x18\x11 \x01(\t\"/\n\x1a\x42inaryOptionsMarketRequest\x12\x11\n\tmarket_id\x18\x01 \x01(\t\"i\n\x1b\x42inaryOptionsMarketResponse\x12J\n\x06market\x18\x01 \x01(\x0b\x32:.injective_derivative_exchange_rpc.BinaryOptionsMarketInfo\"%\n\x10OrderbookRequest\x12\x11\n\tmarket_id\x18\x01 \x01(\t\"c\n\x11OrderbookResponse\x12N\n\torderbook\x18\x01 \x01(\x0b\x32;.injective_derivative_exchange_rpc.DerivativeLimitOrderbook\"\x95\x01\n\x18\x44\x65rivativeLimitOrderbook\x12;\n\x04\x62uys\x18\x01 \x03(\x0b\x32-.injective_derivative_exchange_rpc.PriceLevel\x12<\n\x05sells\x18\x02 \x03(\x0b\x32-.injective_derivative_exchange_rpc.PriceLevel\"@\n\nPriceLevel\x12\r\n\x05price\x18\x01 \x01(\t\x12\x10\n\x08quantity\x18\x02 \x01(\t\x12\x11\n\ttimestamp\x18\x03 \x01(\x12\"\'\n\x11OrderbooksRequest\x12\x12\n\nmarket_ids\x18\x01 \x03(\t\"k\n\x12OrderbooksResponse\x12U\n\norderbooks\x18\x01 \x03(\x0b\x32\x41.injective_derivative_exchange_rpc.SingleDerivativeLimitOrderbook\"\x83\x01\n\x1eSingleDerivativeLimitOrderbook\x12\x11\n\tmarket_id\x18\x01 \x01(\t\x12N\n\torderbook\x18\x02 \x01(\x0b\x32;.injective_derivative_exchange_rpc.DerivativeLimitOrderbook\",\n\x16StreamOrderbookRequest\x12\x12\n\nmarket_ids\x18\x01 \x03(\t\"\xa7\x01\n\x17StreamOrderbookResponse\x12N\n\torderbook\x18\x01 \x01(\x0b\x32;.injective_derivative_exchange_rpc.DerivativeLimitOrderbook\x12\x16\n\x0eoperation_type\x18\x02 \x01(\t\x12\x11\n\ttimestamp\x18\x03 \x01(\x12\x12\x11\n\tmarket_id\x18\x04 \x01(\t\"\xea\x01\n\rOrdersRequest\x12\x11\n\tmarket_id\x18\x01 \x01(\t\x12\x12\n\norder_side\x18\x02 \x01(\t\x12\x15\n\rsubaccount_id\x18\x03 \x01(\t\x12\x0c\n\x04skip\x18\x04 \x01(\x04\x12\r\n\x05limit\x18\x05 \x01(\x11\x12\x12\n\nstart_time\x18\x06 \x01(\x12\x12\x10\n\x08\x65nd_time\x18\x07 \x01(\x12\x12\x12\n\nmarket_ids\x18\x08 \x03(\t\x12\x16\n\x0eis_conditional\x18\t \x01(\t\x12\x12\n\norder_type\x18\n \x01(\t\x12\x18\n\x10include_inactive\x18\x0b \x01(\x08\"\x94\x01\n\x0eOrdersResponse\x12G\n\x06orders\x18\x01 \x03(\x0b\x32\x37.injective_derivative_exchange_rpc.DerivativeLimitOrder\x12\x39\n\x06paging\x18\x02 \x01(\x0b\x32).injective_derivative_exchange_rpc.Paging\"\xba\x03\n\x14\x44\x65rivativeLimitOrder\x12\x12\n\norder_hash\x18\x01 \x01(\t\x12\x12\n\norder_side\x18\x02 \x01(\t\x12\x11\n\tmarket_id\x18\x03 \x01(\t\x12\x15\n\rsubaccount_id\x18\x04 \x01(\t\x12\x16\n\x0eis_reduce_only\x18\x05 \x01(\x08\x12\x0e\n\x06margin\x18\x06 \x01(\t\x12\r\n\x05price\x18\x07 \x01(\t\x12\x10\n\x08quantity\x18\x08 \x01(\t\x12\x19\n\x11unfilled_quantity\x18\t \x01(\t\x12\x15\n\rtrigger_price\x18\n \x01(\t\x12\x15\n\rfee_recipient\x18\x0b \x01(\t\x12\r\n\x05state\x18\x0c \x01(\t\x12\x12\n\ncreated_at\x18\r \x01(\x12\x12\x12\n\nupdated_at\x18\x0e \x01(\x12\x12\x14\n\x0corder_number\x18\x0f \x01(\x12\x12\x12\n\norder_type\x18\x10 \x01(\t\x12\x16\n\x0eis_conditional\x18\x11 \x01(\x08\x12\x12\n\ntrigger_at\x18\x12 \x01(\x04\x12\x19\n\x11placed_order_hash\x18\x13 \x01(\t\x12\x16\n\x0e\x65xecution_type\x18\x14 \x01(\t\"1\n\x06Paging\x12\r\n\x05total\x18\x01 \x01(\x12\x12\x0c\n\x04\x66rom\x18\x02 \x01(\x11\x12\n\n\x02to\x18\x03 \x01(\x11\"\xa6\x01\n\x10PositionsRequest\x12\x15\n\rsubaccount_id\x18\x01 \x01(\t\x12\x11\n\tmarket_id\x18\x02 \x01(\t\x12\x0c\n\x04skip\x18\x03 \x01(\x04\x12\r\n\x05limit\x18\x04 \x01(\x11\x12\x12\n\nstart_time\x18\x05 \x01(\x12\x12\x10\n\x08\x65nd_time\x18\x06 \x01(\x12\x12\x12\n\nmarket_ids\x18\x07 \x03(\t\x12\x11\n\tdirection\x18\x08 \x01(\t\"\x98\x01\n\x11PositionsResponse\x12H\n\tpositions\x18\x01 \x03(\x0b\x32\x35.injective_derivative_exchange_rpc.DerivativePosition\x12\x39\n\x06paging\x18\x02 \x01(\x0b\x32).injective_derivative_exchange_rpc.Paging\"\x83\x02\n\x12\x44\x65rivativePosition\x12\x0e\n\x06ticker\x18\x01 \x01(\t\x12\x11\n\tmarket_id\x18\x02 \x01(\t\x12\x15\n\rsubaccount_id\x18\x03 \x01(\t\x12\x11\n\tdirection\x18\x04 \x01(\t\x12\x10\n\x08quantity\x18\x05 \x01(\t\x12\x13\n\x0b\x65ntry_price\x18\x06 \x01(\t\x12\x0e\n\x06margin\x18\x07 \x01(\t\x12\x19\n\x11liquidation_price\x18\x08 \x01(\t\x12\x12\n\nmark_price\x18\t \x01(\t\x12&\n\x1e\x61ggregate_reduce_only_quantity\x18\x0b \x01(\t\x12\x12\n\nupdated_at\x18\x0c \x01(\x12\"L\n\x1aLiquidablePositionsRequest\x12\x11\n\tmarket_id\x18\x01 \x01(\t\x12\x0c\n\x04skip\x18\x02 \x01(\x04\x12\r\n\x05limit\x18\x03 \x01(\x11\"g\n\x1bLiquidablePositionsResponse\x12H\n\tpositions\x18\x01 \x03(\x0b\x32\x35.injective_derivative_exchange_rpc.DerivativePosition\"\x85\x01\n\x16\x46undingPaymentsRequest\x12\x15\n\rsubaccount_id\x18\x01 \x01(\t\x12\x11\n\tmarket_id\x18\x02 \x01(\t\x12\x0c\n\x04skip\x18\x03 \x01(\x04\x12\r\n\x05limit\x18\x04 \x01(\x11\x12\x10\n\x08\x65nd_time\x18\x05 \x01(\x12\x12\x12\n\nmarket_ids\x18\x06 \x03(\t\"\x99\x01\n\x17\x46undingPaymentsResponse\x12\x43\n\x08payments\x18\x01 \x03(\x0b\x32\x31.injective_derivative_exchange_rpc.FundingPayment\x12\x39\n\x06paging\x18\x02 \x01(\x0b\x32).injective_derivative_exchange_rpc.Paging\"]\n\x0e\x46undingPayment\x12\x11\n\tmarket_id\x18\x01 \x01(\t\x12\x15\n\rsubaccount_id\x18\x02 \x01(\t\x12\x0e\n\x06\x61mount\x18\x03 \x01(\t\x12\x11\n\ttimestamp\x18\x04 \x01(\x12\"W\n\x13\x46undingRatesRequest\x12\x11\n\tmarket_id\x18\x01 \x01(\t\x12\x0c\n\x04skip\x18\x02 \x01(\x04\x12\r\n\x05limit\x18\x03 \x01(\x11\x12\x10\n\x08\x65nd_time\x18\x04 \x01(\x12\"\x98\x01\n\x14\x46undingRatesResponse\x12\x45\n\rfunding_rates\x18\x01 \x03(\x0b\x32..injective_derivative_exchange_rpc.FundingRate\x12\x39\n\x06paging\x18\x02 \x01(\x0b\x32).injective_derivative_exchange_rpc.Paging\"A\n\x0b\x46undingRate\x12\x11\n\tmarket_id\x18\x01 \x01(\t\x12\x0c\n\x04rate\x18\x02 \x01(\t\x12\x11\n\ttimestamp\x18\x03 \x01(\x12\"n\n\x16StreamPositionsRequest\x12\x15\n\rsubaccount_id\x18\x01 \x01(\t\x12\x11\n\tmarket_id\x18\x02 \x01(\t\x12\x12\n\nmarket_ids\x18\x03 \x03(\t\x12\x16\n\x0esubaccount_ids\x18\x04 \x03(\t\"u\n\x17StreamPositionsResponse\x12G\n\x08position\x18\x01 \x01(\x0b\x32\x35.injective_derivative_exchange_rpc.DerivativePosition\x12\x11\n\ttimestamp\x18\x02 \x01(\x12\"\xf0\x01\n\x13StreamOrdersRequest\x12\x11\n\tmarket_id\x18\x01 \x01(\t\x12\x12\n\norder_side\x18\x02 \x01(\t\x12\x15\n\rsubaccount_id\x18\x03 \x01(\t\x12\x0c\n\x04skip\x18\x04 \x01(\x04\x12\r\n\x05limit\x18\x05 \x01(\x11\x12\x12\n\nstart_time\x18\x06 \x01(\x12\x12\x10\n\x08\x65nd_time\x18\x07 \x01(\x12\x12\x12\n\nmarket_ids\x18\x08 \x03(\t\x12\x16\n\x0eis_conditional\x18\t \x01(\t\x12\x12\n\norder_type\x18\n \x01(\t\x12\x18\n\x10include_inactive\x18\x0b \x01(\x08\"\x89\x01\n\x14StreamOrdersResponse\x12\x46\n\x05order\x18\x01 \x01(\x0b\x32\x37.injective_derivative_exchange_rpc.DerivativeLimitOrder\x12\x16\n\x0eoperation_type\x18\x02 \x01(\t\x12\x11\n\ttimestamp\x18\x03 \x01(\x12\"\xec\x01\n\rTradesRequest\x12\x11\n\tmarket_id\x18\x01 \x01(\t\x12\x16\n\x0e\x65xecution_side\x18\x02 \x01(\t\x12\x11\n\tdirection\x18\x03 \x01(\t\x12\x15\n\rsubaccount_id\x18\x04 \x01(\t\x12\x0c\n\x04skip\x18\x05 \x01(\x04\x12\r\n\x05limit\x18\x06 \x01(\x11\x12\x12\n\nstart_time\x18\x07 \x01(\x12\x12\x10\n\x08\x65nd_time\x18\x08 \x01(\x12\x12\x12\n\nmarket_ids\x18\t \x03(\t\x12\x16\n\x0esubaccount_ids\x18\n \x03(\t\x12\x17\n\x0f\x65xecution_types\x18\x0b \x03(\t\"\x8f\x01\n\x0eTradesResponse\x12\x42\n\x06trades\x18\x01 \x03(\x0b\x32\x32.injective_derivative_exchange_rpc.DerivativeTrade\x12\x39\n\x06paging\x18\x02 \x01(\x0b\x32).injective_derivative_exchange_rpc.Paging\"\xaa\x02\n\x0f\x44\x65rivativeTrade\x12\x12\n\norder_hash\x18\x01 \x01(\t\x12\x15\n\rsubaccount_id\x18\x02 \x01(\t\x12\x11\n\tmarket_id\x18\x03 \x01(\t\x12\x1c\n\x14trade_execution_type\x18\x04 \x01(\t\x12\x16\n\x0eis_liquidation\x18\x05 \x01(\x08\x12H\n\x0eposition_delta\x18\x06 \x01(\x0b\x32\x30.injective_derivative_exchange_rpc.PositionDelta\x12\x0e\n\x06payout\x18\x07 \x01(\t\x12\x0b\n\x03\x66\x65\x65\x18\x08 \x01(\t\x12\x13\n\x0b\x65xecuted_at\x18\t \x01(\x12\x12\x15\n\rfee_recipient\x18\n \x01(\t\x12\x10\n\x08trade_id\x18\x0b \x01(\t\"w\n\rPositionDelta\x12\x17\n\x0ftrade_direction\x18\x01 \x01(\t\x12\x17\n\x0f\x65xecution_price\x18\x02 \x01(\t\x12\x1a\n\x12\x65xecution_quantity\x18\x03 \x01(\t\x12\x18\n\x10\x65xecution_margin\x18\x04 \x01(\t\"\xf2\x01\n\x13StreamTradesRequest\x12\x11\n\tmarket_id\x18\x01 \x01(\t\x12\x16\n\x0e\x65xecution_side\x18\x02 \x01(\t\x12\x11\n\tdirection\x18\x03 \x01(\t\x12\x15\n\rsubaccount_id\x18\x04 \x01(\t\x12\x0c\n\x04skip\x18\x05 \x01(\x04\x12\r\n\x05limit\x18\x06 \x01(\x11\x12\x12\n\nstart_time\x18\x07 \x01(\x12\x12\x10\n\x08\x65nd_time\x18\x08 \x01(\x12\x12\x12\n\nmarket_ids\x18\t \x03(\t\x12\x16\n\x0esubaccount_ids\x18\n \x03(\t\x12\x17\n\x0f\x65xecution_types\x18\x0b \x03(\t\"\x84\x01\n\x14StreamTradesResponse\x12\x41\n\x05trade\x18\x01 \x01(\x0b\x32\x32.injective_derivative_exchange_rpc.DerivativeTrade\x12\x16\n\x0eoperation_type\x18\x02 \x01(\t\x12\x11\n\ttimestamp\x18\x03 \x01(\x12\"d\n\x1bSubaccountOrdersListRequest\x12\x15\n\rsubaccount_id\x18\x01 \x01(\t\x12\x11\n\tmarket_id\x18\x02 \x01(\t\x12\x0c\n\x04skip\x18\x03 \x01(\x04\x12\r\n\x05limit\x18\x04 \x01(\x11\"\xa2\x01\n\x1cSubaccountOrdersListResponse\x12G\n\x06orders\x18\x01 \x03(\x0b\x32\x37.injective_derivative_exchange_rpc.DerivativeLimitOrder\x12\x39\n\x06paging\x18\x02 \x01(\x0b\x32).injective_derivative_exchange_rpc.Paging\"\x8f\x01\n\x1bSubaccountTradesListRequest\x12\x15\n\rsubaccount_id\x18\x01 \x01(\t\x12\x11\n\tmarket_id\x18\x02 \x01(\t\x12\x16\n\x0e\x65xecution_type\x18\x03 \x01(\t\x12\x11\n\tdirection\x18\x04 \x01(\t\x12\x0c\n\x04skip\x18\x05 \x01(\x04\x12\r\n\x05limit\x18\x06 \x01(\x11\"b\n\x1cSubaccountTradesListResponse\x12\x42\n\x06trades\x18\x01 \x03(\x0b\x32\x32.injective_derivative_exchange_rpc.DerivativeTrade\"\xeb\x01\n\x14OrdersHistoryRequest\x12\x15\n\rsubaccount_id\x18\x01 \x01(\t\x12\x11\n\tmarket_id\x18\x02 \x01(\t\x12\x0c\n\x04skip\x18\x03 \x01(\x04\x12\r\n\x05limit\x18\x04 \x01(\x11\x12\x13\n\x0border_types\x18\x05 \x03(\t\x12\x11\n\tdirection\x18\x06 \x01(\t\x12\x12\n\nstart_time\x18\x07 \x01(\x12\x12\x10\n\x08\x65nd_time\x18\x08 \x01(\x12\x12\x16\n\x0eis_conditional\x18\t \x01(\t\x12\r\n\x05state\x18\x0b \x01(\t\x12\x17\n\x0f\x65xecution_types\x18\x0c \x03(\t\"\x9d\x01\n\x15OrdersHistoryResponse\x12I\n\x06orders\x18\x01 \x03(\x0b\x32\x39.injective_derivative_exchange_rpc.DerivativeOrderHistory\x12\x39\n\x06paging\x18\x02 \x01(\x0b\x32).injective_derivative_exchange_rpc.Paging\"\x9f\x03\n\x16\x44\x65rivativeOrderHistory\x12\x12\n\norder_hash\x18\x01 \x01(\t\x12\x11\n\tmarket_id\x18\x02 \x01(\t\x12\x11\n\tis_active\x18\x03 \x01(\x08\x12\x15\n\rsubaccount_id\x18\x04 \x01(\t\x12\x16\n\x0e\x65xecution_type\x18\x05 \x01(\t\x12\x12\n\norder_type\x18\x06 \x01(\t\x12\r\n\x05price\x18\x07 \x01(\t\x12\x15\n\rtrigger_price\x18\x08 \x01(\t\x12\x10\n\x08quantity\x18\t \x01(\t\x12\x17\n\x0f\x66illed_quantity\x18\n \x01(\t\x12\r\n\x05state\x18\x0b \x01(\t\x12\x12\n\ncreated_at\x18\x0c \x01(\x12\x12\x12\n\nupdated_at\x18\r \x01(\x12\x12\x16\n\x0eis_reduce_only\x18\x0e \x01(\x08\x12\x11\n\tdirection\x18\x0f \x01(\t\x12\x16\n\x0eis_conditional\x18\x10 \x01(\x08\x12\x12\n\ntrigger_at\x18\x11 \x01(\x04\x12\x19\n\x11placed_order_hash\x18\x12 \x01(\t\x12\x0e\n\x06margin\x18\x13 \x01(\t\"\x96\x01\n\x1aStreamOrdersHistoryRequest\x12\x15\n\rsubaccount_id\x18\x01 \x01(\t\x12\x11\n\tmarket_id\x18\x02 \x01(\t\x12\x13\n\x0border_types\x18\x03 \x03(\t\x12\x11\n\tdirection\x18\x04 \x01(\t\x12\r\n\x05state\x18\x05 \x01(\t\x12\x17\n\x0f\x65xecution_types\x18\x06 \x03(\t\"\x92\x01\n\x1bStreamOrdersHistoryResponse\x12H\n\x05order\x18\x01 \x01(\x0b\x32\x39.injective_derivative_exchange_rpc.DerivativeOrderHistory\x12\x16\n\x0eoperation_type\x18\x02 \x01(\t\x12\x11\n\ttimestamp\x18\x03 \x01(\x12\x32\x96\x16\n\x1eInjectiveDerivativeExchangeRPC\x12p\n\x07Markets\x12\x31.injective_derivative_exchange_rpc.MarketsRequest\x1a\x32.injective_derivative_exchange_rpc.MarketsResponse\x12m\n\x06Market\x12\x30.injective_derivative_exchange_rpc.MarketRequest\x1a\x31.injective_derivative_exchange_rpc.MarketResponse\x12\x81\x01\n\x0cStreamMarket\x12\x36.injective_derivative_exchange_rpc.StreamMarketRequest\x1a\x37.injective_derivative_exchange_rpc.StreamMarketResponse0\x01\x12\x97\x01\n\x14\x42inaryOptionsMarkets\x12>.injective_derivative_exchange_rpc.BinaryOptionsMarketsRequest\x1a?.injective_derivative_exchange_rpc.BinaryOptionsMarketsResponse\x12\x94\x01\n\x13\x42inaryOptionsMarket\x12=.injective_derivative_exchange_rpc.BinaryOptionsMarketRequest\x1a>.injective_derivative_exchange_rpc.BinaryOptionsMarketResponse\x12v\n\tOrderbook\x12\x33.injective_derivative_exchange_rpc.OrderbookRequest\x1a\x34.injective_derivative_exchange_rpc.OrderbookResponse\x12y\n\nOrderbooks\x12\x34.injective_derivative_exchange_rpc.OrderbooksRequest\x1a\x35.injective_derivative_exchange_rpc.OrderbooksResponse\x12\x8a\x01\n\x0fStreamOrderbook\x12\x39.injective_derivative_exchange_rpc.StreamOrderbookRequest\x1a:.injective_derivative_exchange_rpc.StreamOrderbookResponse0\x01\x12m\n\x06Orders\x12\x30.injective_derivative_exchange_rpc.OrdersRequest\x1a\x31.injective_derivative_exchange_rpc.OrdersResponse\x12v\n\tPositions\x12\x33.injective_derivative_exchange_rpc.PositionsRequest\x1a\x34.injective_derivative_exchange_rpc.PositionsResponse\x12\x94\x01\n\x13LiquidablePositions\x12=.injective_derivative_exchange_rpc.LiquidablePositionsRequest\x1a>.injective_derivative_exchange_rpc.LiquidablePositionsResponse\x12\x88\x01\n\x0f\x46undingPayments\x12\x39.injective_derivative_exchange_rpc.FundingPaymentsRequest\x1a:.injective_derivative_exchange_rpc.FundingPaymentsResponse\x12\x7f\n\x0c\x46undingRates\x12\x36.injective_derivative_exchange_rpc.FundingRatesRequest\x1a\x37.injective_derivative_exchange_rpc.FundingRatesResponse\x12\x8a\x01\n\x0fStreamPositions\x12\x39.injective_derivative_exchange_rpc.StreamPositionsRequest\x1a:.injective_derivative_exchange_rpc.StreamPositionsResponse0\x01\x12\x81\x01\n\x0cStreamOrders\x12\x36.injective_derivative_exchange_rpc.StreamOrdersRequest\x1a\x37.injective_derivative_exchange_rpc.StreamOrdersResponse0\x01\x12m\n\x06Trades\x12\x30.injective_derivative_exchange_rpc.TradesRequest\x1a\x31.injective_derivative_exchange_rpc.TradesResponse\x12\x81\x01\n\x0cStreamTrades\x12\x36.injective_derivative_exchange_rpc.StreamTradesRequest\x1a\x37.injective_derivative_exchange_rpc.StreamTradesResponse0\x01\x12\x97\x01\n\x14SubaccountOrdersList\x12>.injective_derivative_exchange_rpc.SubaccountOrdersListRequest\x1a?.injective_derivative_exchange_rpc.SubaccountOrdersListResponse\x12\x97\x01\n\x14SubaccountTradesList\x12>.injective_derivative_exchange_rpc.SubaccountTradesListRequest\x1a?.injective_derivative_exchange_rpc.SubaccountTradesListResponse\x12\x82\x01\n\rOrdersHistory\x12\x37.injective_derivative_exchange_rpc.OrdersHistoryRequest\x1a\x38.injective_derivative_exchange_rpc.OrdersHistoryResponse\x12\x96\x01\n\x13StreamOrdersHistory\x12=.injective_derivative_exchange_rpc.StreamOrdersHistoryRequest\x1a>.injective_derivative_exchange_rpc.StreamOrdersHistoryResponse0\x01\x42&Z$/injective_derivative_exchange_rpcpbb\x06proto3'
)




_MARKETSREQUEST = _descriptor.Descriptor(
  name='MarketsRequest',
  full_name='injective_derivative_exchange_rpc.MarketsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market_status', full_name='injective_derivative_exchange_rpc.MarketsRequest.market_status', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quote_denom', full_name='injective_derivative_exchange_rpc.MarketsRequest.quote_denom', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=87,
  serialized_end=147,
)


_MARKETSRESPONSE = _descriptor.Descriptor(
  name='MarketsResponse',
  full_name='injective_derivative_exchange_rpc.MarketsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='markets', full_name='injective_derivative_exchange_rpc.MarketsResponse.markets', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=149,
  serialized_end=240,
)


_DERIVATIVEMARKETINFO = _descriptor.Descriptor(
  name='DerivativeMarketInfo',
  full_name='injective_derivative_exchange_rpc.DerivativeMarketInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective_derivative_exchange_rpc.DerivativeMarketInfo.market_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_status', full_name='injective_derivative_exchange_rpc.DerivativeMarketInfo.market_status', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ticker', full_name='injective_derivative_exchange_rpc.DerivativeMarketInfo.ticker', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oracle_base', full_name='injective_derivative_exchange_rpc.DerivativeMarketInfo.oracle_base', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oracle_quote', full_name='injective_derivative_exchange_rpc.DerivativeMarketInfo.oracle_quote', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oracle_type', full_name='injective_derivative_exchange_rpc.DerivativeMarketInfo.oracle_type', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oracle_scale_factor', full_name='injective_derivative_exchange_rpc.DerivativeMarketInfo.oracle_scale_factor', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='initial_margin_ratio', full_name='injective_derivative_exchange_rpc.DerivativeMarketInfo.initial_margin_ratio', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='maintenance_margin_ratio', full_name='injective_derivative_exchange_rpc.DerivativeMarketInfo.maintenance_margin_ratio', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quote_denom', full_name='injective_derivative_exchange_rpc.DerivativeMarketInfo.quote_denom', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quote_token_meta', full_name='injective_derivative_exchange_rpc.DerivativeMarketInfo.quote_token_meta', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='maker_fee_rate', full_name='injective_derivative_exchange_rpc.DerivativeMarketInfo.maker_fee_rate', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='taker_fee_rate', full_name='injective_derivative_exchange_rpc.DerivativeMarketInfo.taker_fee_rate', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='service_provider_fee', full_name='injective_derivative_exchange_rpc.DerivativeMarketInfo.service_provider_fee', index=13,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_perpetual', full_name='injective_derivative_exchange_rpc.DerivativeMarketInfo.is_perpetual', index=14,
      number=15, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_price_tick_size', full_name='injective_derivative_exchange_rpc.DerivativeMarketInfo.min_price_tick_size', index=15,
      number=16, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_quantity_tick_size', full_name='injective_derivative_exchange_rpc.DerivativeMarketInfo.min_quantity_tick_size', index=16,
      number=17, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='perpetual_market_info', full_name='injective_derivative_exchange_rpc.DerivativeMarketInfo.perpetual_market_info', index=17,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='perpetual_market_funding', full_name='injective_derivative_exchange_rpc.DerivativeMarketInfo.perpetual_market_funding', index=18,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expiry_futures_market_info', full_name='injective_derivative_exchange_rpc.DerivativeMarketInfo.expiry_futures_market_info', index=19,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=243,
  serialized_end=1010,
)


_TOKENMETA = _descriptor.Descriptor(
  name='TokenMeta',
  full_name='injective_derivative_exchange_rpc.TokenMeta',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='injective_derivative_exchange_rpc.TokenMeta.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='address', full_name='injective_derivative_exchange_rpc.TokenMeta.address', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='symbol', full_name='injective_derivative_exchange_rpc.TokenMeta.symbol', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='logo', full_name='injective_derivative_exchange_rpc.TokenMeta.logo', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decimals', full_name='injective_derivative_exchange_rpc.TokenMeta.decimals', index=4,
      number=5, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updated_at', full_name='injective_derivative_exchange_rpc.TokenMeta.updated_at', index=5,
      number=6, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1012,
  serialized_end=1122,
)


_PERPETUALMARKETINFO = _descriptor.Descriptor(
  name='PerpetualMarketInfo',
  full_name='injective_derivative_exchange_rpc.PerpetualMarketInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='hourly_funding_rate_cap', full_name='injective_derivative_exchange_rpc.PerpetualMarketInfo.hourly_funding_rate_cap', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hourly_interest_rate', full_name='injective_derivative_exchange_rpc.PerpetualMarketInfo.hourly_interest_rate', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_funding_timestamp', full_name='injective_derivative_exchange_rpc.PerpetualMarketInfo.next_funding_timestamp', index=2,
      number=3, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='funding_interval', full_name='injective_derivative_exchange_rpc.PerpetualMarketInfo.funding_interval', index=3,
      number=4, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1125,
  serialized_end=1267,
)


_PERPETUALMARKETFUNDING = _descriptor.Descriptor(
  name='PerpetualMarketFunding',
  full_name='injective_derivative_exchange_rpc.PerpetualMarketFunding',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cumulative_funding', full_name='injective_derivative_exchange_rpc.PerpetualMarketFunding.cumulative_funding', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cumulative_price', full_name='injective_derivative_exchange_rpc.PerpetualMarketFunding.cumulative_price', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_timestamp', full_name='injective_derivative_exchange_rpc.PerpetualMarketFunding.last_timestamp', index=2,
      number=3, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1269,
  serialized_end=1371,
)


_EXPIRYFUTURESMARKETINFO = _descriptor.Descriptor(
  name='ExpiryFuturesMarketInfo',
  full_name='injective_derivative_exchange_rpc.ExpiryFuturesMarketInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='expiration_timestamp', full_name='injective_derivative_exchange_rpc.ExpiryFuturesMarketInfo.expiration_timestamp', index=0,
      number=1, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='settlement_price', full_name='injective_derivative_exchange_rpc.ExpiryFuturesMarketInfo.settlement_price', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1373,
  serialized_end=1454,
)


_MARKETREQUEST = _descriptor.Descriptor(
  name='MarketRequest',
  full_name='injective_derivative_exchange_rpc.MarketRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective_derivative_exchange_rpc.MarketRequest.market_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1456,
  serialized_end=1490,
)


_MARKETRESPONSE = _descriptor.Descriptor(
  name='MarketResponse',
  full_name='injective_derivative_exchange_rpc.MarketResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market', full_name='injective_derivative_exchange_rpc.MarketResponse.market', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1492,
  serialized_end=1581,
)


_STREAMMARKETREQUEST = _descriptor.Descriptor(
  name='StreamMarketRequest',
  full_name='injective_derivative_exchange_rpc.StreamMarketRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market_ids', full_name='injective_derivative_exchange_rpc.StreamMarketRequest.market_ids', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1583,
  serialized_end=1624,
)


_STREAMMARKETRESPONSE = _descriptor.Descriptor(
  name='StreamMarketResponse',
  full_name='injective_derivative_exchange_rpc.StreamMarketResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market', full_name='injective_derivative_exchange_rpc.StreamMarketResponse.market', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='operation_type', full_name='injective_derivative_exchange_rpc.StreamMarketResponse.operation_type', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='injective_derivative_exchange_rpc.StreamMarketResponse.timestamp', index=2,
      number=3, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1627,
  serialized_end=1765,
)


_BINARYOPTIONSMARKETSREQUEST = _descriptor.Descriptor(
  name='BinaryOptionsMarketsRequest',
  full_name='injective_derivative_exchange_rpc.BinaryOptionsMarketsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market_status', full_name='injective_derivative_exchange_rpc.BinaryOptionsMarketsRequest.market_status', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quote_denom', full_name='injective_derivative_exchange_rpc.BinaryOptionsMarketsRequest.quote_denom', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1767,
  serialized_end=1840,
)


_BINARYOPTIONSMARKETSRESPONSE = _descriptor.Descriptor(
  name='BinaryOptionsMarketsResponse',
  full_name='injective_derivative_exchange_rpc.BinaryOptionsMarketsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='markets', full_name='injective_derivative_exchange_rpc.BinaryOptionsMarketsResponse.markets', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1842,
  serialized_end=1949,
)


_BINARYOPTIONSMARKETINFO = _descriptor.Descriptor(
  name='BinaryOptionsMarketInfo',
  full_name='injective_derivative_exchange_rpc.BinaryOptionsMarketInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective_derivative_exchange_rpc.BinaryOptionsMarketInfo.market_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_status', full_name='injective_derivative_exchange_rpc.BinaryOptionsMarketInfo.market_status', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ticker', full_name='injective_derivative_exchange_rpc.BinaryOptionsMarketInfo.ticker', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oracle_symbol', full_name='injective_derivative_exchange_rpc.BinaryOptionsMarketInfo.oracle_symbol', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oracle_provider', full_name='injective_derivative_exchange_rpc.BinaryOptionsMarketInfo.oracle_provider', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oracle_type', full_name='injective_derivative_exchange_rpc.BinaryOptionsMarketInfo.oracle_type', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oracle_scale_factor', full_name='injective_derivative_exchange_rpc.BinaryOptionsMarketInfo.oracle_scale_factor', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expiration_timestamp', full_name='injective_derivative_exchange_rpc.BinaryOptionsMarketInfo.expiration_timestamp', index=7,
      number=8, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='settlement_timestamp', full_name='injective_derivative_exchange_rpc.BinaryOptionsMarketInfo.settlement_timestamp', index=8,
      number=9, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quote_denom', full_name='injective_derivative_exchange_rpc.BinaryOptionsMarketInfo.quote_denom', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quote_token_meta', full_name='injective_derivative_exchange_rpc.BinaryOptionsMarketInfo.quote_token_meta', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='maker_fee_rate', full_name='injective_derivative_exchange_rpc.BinaryOptionsMarketInfo.maker_fee_rate', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='taker_fee_rate', full_name='injective_derivative_exchange_rpc.BinaryOptionsMarketInfo.taker_fee_rate', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='service_provider_fee', full_name='injective_derivative_exchange_rpc.BinaryOptionsMarketInfo.service_provider_fee', index=13,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_price_tick_size', full_name='injective_derivative_exchange_rpc.BinaryOptionsMarketInfo.min_price_tick_size', index=14,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_quantity_tick_size', full_name='injective_derivative_exchange_rpc.BinaryOptionsMarketInfo.min_quantity_tick_size', index=15,
      number=16, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='settlement_price', full_name='injective_derivative_exchange_rpc.BinaryOptionsMarketInfo.settlement_price', index=16,
      number=17, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1952,
  serialized_end=2451,
)


_BINARYOPTIONSMARKETREQUEST = _descriptor.Descriptor(
  name='BinaryOptionsMarketRequest',
  full_name='injective_derivative_exchange_rpc.BinaryOptionsMarketRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective_derivative_exchange_rpc.BinaryOptionsMarketRequest.market_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2453,
  serialized_end=2500,
)


_BINARYOPTIONSMARKETRESPONSE = _descriptor.Descriptor(
  name='BinaryOptionsMarketResponse',
  full_name='injective_derivative_exchange_rpc.BinaryOptionsMarketResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market', full_name='injective_derivative_exchange_rpc.BinaryOptionsMarketResponse.market', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2502,
  serialized_end=2607,
)


_ORDERBOOKREQUEST = _descriptor.Descriptor(
  name='OrderbookRequest',
  full_name='injective_derivative_exchange_rpc.OrderbookRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective_derivative_exchange_rpc.OrderbookRequest.market_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2609,
  serialized_end=2646,
)


_ORDERBOOKRESPONSE = _descriptor.Descriptor(
  name='OrderbookResponse',
  full_name='injective_derivative_exchange_rpc.OrderbookResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='orderbook', full_name='injective_derivative_exchange_rpc.OrderbookResponse.orderbook', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2648,
  serialized_end=2747,
)


_DERIVATIVELIMITORDERBOOK = _descriptor.Descriptor(
  name='DerivativeLimitOrderbook',
  full_name='injective_derivative_exchange_rpc.DerivativeLimitOrderbook',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='buys', full_name='injective_derivative_exchange_rpc.DerivativeLimitOrderbook.buys', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sells', full_name='injective_derivative_exchange_rpc.DerivativeLimitOrderbook.sells', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2750,
  serialized_end=2899,
)


_PRICELEVEL = _descriptor.Descriptor(
  name='PriceLevel',
  full_name='injective_derivative_exchange_rpc.PriceLevel',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='price', full_name='injective_derivative_exchange_rpc.PriceLevel.price', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quantity', full_name='injective_derivative_exchange_rpc.PriceLevel.quantity', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='injective_derivative_exchange_rpc.PriceLevel.timestamp', index=2,
      number=3, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2901,
  serialized_end=2965,
)


_ORDERBOOKSREQUEST = _descriptor.Descriptor(
  name='OrderbooksRequest',
  full_name='injective_derivative_exchange_rpc.OrderbooksRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market_ids', full_name='injective_derivative_exchange_rpc.OrderbooksRequest.market_ids', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2967,
  serialized_end=3006,
)


_ORDERBOOKSRESPONSE = _descriptor.Descriptor(
  name='OrderbooksResponse',
  full_name='injective_derivative_exchange_rpc.OrderbooksResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='orderbooks', full_name='injective_derivative_exchange_rpc.OrderbooksResponse.orderbooks', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3008,
  serialized_end=3115,
)


_SINGLEDERIVATIVELIMITORDERBOOK = _descriptor.Descriptor(
  name='SingleDerivativeLimitOrderbook',
  full_name='injective_derivative_exchange_rpc.SingleDerivativeLimitOrderbook',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective_derivative_exchange_rpc.SingleDerivativeLimitOrderbook.market_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='orderbook', full_name='injective_derivative_exchange_rpc.SingleDerivativeLimitOrderbook.orderbook', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3118,
  serialized_end=3249,
)


_STREAMORDERBOOKREQUEST = _descriptor.Descriptor(
  name='StreamOrderbookRequest',
  full_name='injective_derivative_exchange_rpc.StreamOrderbookRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market_ids', full_name='injective_derivative_exchange_rpc.StreamOrderbookRequest.market_ids', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3251,
  serialized_end=3295,
)


_STREAMORDERBOOKRESPONSE = _descriptor.Descriptor(
  name='StreamOrderbookResponse',
  full_name='injective_derivative_exchange_rpc.StreamOrderbookResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='orderbook', full_name='injective_derivative_exchange_rpc.StreamOrderbookResponse.orderbook', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='operation_type', full_name='injective_derivative_exchange_rpc.StreamOrderbookResponse.operation_type', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='injective_derivative_exchange_rpc.StreamOrderbookResponse.timestamp', index=2,
      number=3, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective_derivative_exchange_rpc.StreamOrderbookResponse.market_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3298,
  serialized_end=3465,
)


_ORDERSREQUEST = _descriptor.Descriptor(
  name='OrdersRequest',
  full_name='injective_derivative_exchange_rpc.OrdersRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective_derivative_exchange_rpc.OrdersRequest.market_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order_side', full_name='injective_derivative_exchange_rpc.OrdersRequest.order_side', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subaccount_id', full_name='injective_derivative_exchange_rpc.OrdersRequest.subaccount_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='skip', full_name='injective_derivative_exchange_rpc.OrdersRequest.skip', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='limit', full_name='injective_derivative_exchange_rpc.OrdersRequest.limit', index=4,
      number=5, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_time', full_name='injective_derivative_exchange_rpc.OrdersRequest.start_time', index=5,
      number=6, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_time', full_name='injective_derivative_exchange_rpc.OrdersRequest.end_time', index=6,
      number=7, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_ids', full_name='injective_derivative_exchange_rpc.OrdersRequest.market_ids', index=7,
      number=8, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_conditional', full_name='injective_derivative_exchange_rpc.OrdersRequest.is_conditional', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order_type', full_name='injective_derivative_exchange_rpc.OrdersRequest.order_type', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='include_inactive', full_name='injective_derivative_exchange_rpc.OrdersRequest.include_inactive', index=10,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3468,
  serialized_end=3702,
)


_ORDERSRESPONSE = _descriptor.Descriptor(
  name='OrdersResponse',
  full_name='injective_derivative_exchange_rpc.OrdersResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='orders', full_name='injective_derivative_exchange_rpc.OrdersResponse.orders', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='paging', full_name='injective_derivative_exchange_rpc.OrdersResponse.paging', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3705,
  serialized_end=3853,
)


_DERIVATIVELIMITORDER = _descriptor.Descriptor(
  name='DerivativeLimitOrder',
  full_name='injective_derivative_exchange_rpc.DerivativeLimitOrder',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='order_hash', full_name='injective_derivative_exchange_rpc.DerivativeLimitOrder.order_hash', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order_side', full_name='injective_derivative_exchange_rpc.DerivativeLimitOrder.order_side', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective_derivative_exchange_rpc.DerivativeLimitOrder.market_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subaccount_id', full_name='injective_derivative_exchange_rpc.DerivativeLimitOrder.subaccount_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_reduce_only', full_name='injective_derivative_exchange_rpc.DerivativeLimitOrder.is_reduce_only', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='margin', full_name='injective_derivative_exchange_rpc.DerivativeLimitOrder.margin', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='price', full_name='injective_derivative_exchange_rpc.DerivativeLimitOrder.price', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quantity', full_name='injective_derivative_exchange_rpc.DerivativeLimitOrder.quantity', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unfilled_quantity', full_name='injective_derivative_exchange_rpc.DerivativeLimitOrder.unfilled_quantity', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trigger_price', full_name='injective_derivative_exchange_rpc.DerivativeLimitOrder.trigger_price', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fee_recipient', full_name='injective_derivative_exchange_rpc.DerivativeLimitOrder.fee_recipient', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='injective_derivative_exchange_rpc.DerivativeLimitOrder.state', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='injective_derivative_exchange_rpc.DerivativeLimitOrder.created_at', index=12,
      number=13, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updated_at', full_name='injective_derivative_exchange_rpc.DerivativeLimitOrder.updated_at', index=13,
      number=14, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order_number', full_name='injective_derivative_exchange_rpc.DerivativeLimitOrder.order_number', index=14,
      number=15, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order_type', full_name='injective_derivative_exchange_rpc.DerivativeLimitOrder.order_type', index=15,
      number=16, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_conditional', full_name='injective_derivative_exchange_rpc.DerivativeLimitOrder.is_conditional', index=16,
      number=17, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trigger_at', full_name='injective_derivative_exchange_rpc.DerivativeLimitOrder.trigger_at', index=17,
      number=18, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='placed_order_hash', full_name='injective_derivative_exchange_rpc.DerivativeLimitOrder.placed_order_hash', index=18,
      number=19, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='execution_type', full_name='injective_derivative_exchange_rpc.DerivativeLimitOrder.execution_type', index=19,
      number=20, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3856,
  serialized_end=4298,
)


_PAGING = _descriptor.Descriptor(
  name='Paging',
  full_name='injective_derivative_exchange_rpc.Paging',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='total', full_name='injective_derivative_exchange_rpc.Paging.total', index=0,
      number=1, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='from', full_name='injective_derivative_exchange_rpc.Paging.from', index=1,
      number=2, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='to', full_name='injective_derivative_exchange_rpc.Paging.to', index=2,
      number=3, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4300,
  serialized_end=4349,
)


_POSITIONSREQUEST = _descriptor.Descriptor(
  name='PositionsRequest',
  full_name='injective_derivative_exchange_rpc.PositionsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subaccount_id', full_name='injective_derivative_exchange_rpc.PositionsRequest.subaccount_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective_derivative_exchange_rpc.PositionsRequest.market_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='skip', full_name='injective_derivative_exchange_rpc.PositionsRequest.skip', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='limit', full_name='injective_derivative_exchange_rpc.PositionsRequest.limit', index=3,
      number=4, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_time', full_name='injective_derivative_exchange_rpc.PositionsRequest.start_time', index=4,
      number=5, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_time', full_name='injective_derivative_exchange_rpc.PositionsRequest.end_time', index=5,
      number=6, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_ids', full_name='injective_derivative_exchange_rpc.PositionsRequest.market_ids', index=6,
      number=7, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='direction', full_name='injective_derivative_exchange_rpc.PositionsRequest.direction', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4352,
  serialized_end=4518,
)


_POSITIONSRESPONSE = _descriptor.Descriptor(
  name='PositionsResponse',
  full_name='injective_derivative_exchange_rpc.PositionsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='positions', full_name='injective_derivative_exchange_rpc.PositionsResponse.positions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='paging', full_name='injective_derivative_exchange_rpc.PositionsResponse.paging', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4521,
  serialized_end=4673,
)


_DERIVATIVEPOSITION = _descriptor.Descriptor(
  name='DerivativePosition',
  full_name='injective_derivative_exchange_rpc.DerivativePosition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ticker', full_name='injective_derivative_exchange_rpc.DerivativePosition.ticker', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective_derivative_exchange_rpc.DerivativePosition.market_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subaccount_id', full_name='injective_derivative_exchange_rpc.DerivativePosition.subaccount_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='direction', full_name='injective_derivative_exchange_rpc.DerivativePosition.direction', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quantity', full_name='injective_derivative_exchange_rpc.DerivativePosition.quantity', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='entry_price', full_name='injective_derivative_exchange_rpc.DerivativePosition.entry_price', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='margin', full_name='injective_derivative_exchange_rpc.DerivativePosition.margin', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='liquidation_price', full_name='injective_derivative_exchange_rpc.DerivativePosition.liquidation_price', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mark_price', full_name='injective_derivative_exchange_rpc.DerivativePosition.mark_price', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='aggregate_reduce_only_quantity', full_name='injective_derivative_exchange_rpc.DerivativePosition.aggregate_reduce_only_quantity', index=9,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updated_at', full_name='injective_derivative_exchange_rpc.DerivativePosition.updated_at', index=10,
      number=12, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4676,
  serialized_end=4935,
)


_LIQUIDABLEPOSITIONSREQUEST = _descriptor.Descriptor(
  name='LiquidablePositionsRequest',
  full_name='injective_derivative_exchange_rpc.LiquidablePositionsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective_derivative_exchange_rpc.LiquidablePositionsRequest.market_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='skip', full_name='injective_derivative_exchange_rpc.LiquidablePositionsRequest.skip', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='limit', full_name='injective_derivative_exchange_rpc.LiquidablePositionsRequest.limit', index=2,
      number=3, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4937,
  serialized_end=5013,
)


_LIQUIDABLEPOSITIONSRESPONSE = _descriptor.Descriptor(
  name='LiquidablePositionsResponse',
  full_name='injective_derivative_exchange_rpc.LiquidablePositionsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='positions', full_name='injective_derivative_exchange_rpc.LiquidablePositionsResponse.positions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5015,
  serialized_end=5118,
)


_FUNDINGPAYMENTSREQUEST = _descriptor.Descriptor(
  name='FundingPaymentsRequest',
  full_name='injective_derivative_exchange_rpc.FundingPaymentsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subaccount_id', full_name='injective_derivative_exchange_rpc.FundingPaymentsRequest.subaccount_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective_derivative_exchange_rpc.FundingPaymentsRequest.market_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='skip', full_name='injective_derivative_exchange_rpc.FundingPaymentsRequest.skip', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='limit', full_name='injective_derivative_exchange_rpc.FundingPaymentsRequest.limit', index=3,
      number=4, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_time', full_name='injective_derivative_exchange_rpc.FundingPaymentsRequest.end_time', index=4,
      number=5, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_ids', full_name='injective_derivative_exchange_rpc.FundingPaymentsRequest.market_ids', index=5,
      number=6, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5121,
  serialized_end=5254,
)


_FUNDINGPAYMENTSRESPONSE = _descriptor.Descriptor(
  name='FundingPaymentsResponse',
  full_name='injective_derivative_exchange_rpc.FundingPaymentsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='payments', full_name='injective_derivative_exchange_rpc.FundingPaymentsResponse.payments', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='paging', full_name='injective_derivative_exchange_rpc.FundingPaymentsResponse.paging', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5257,
  serialized_end=5410,
)


_FUNDINGPAYMENT = _descriptor.Descriptor(
  name='FundingPayment',
  full_name='injective_derivative_exchange_rpc.FundingPayment',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective_derivative_exchange_rpc.FundingPayment.market_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subaccount_id', full_name='injective_derivative_exchange_rpc.FundingPayment.subaccount_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='amount', full_name='injective_derivative_exchange_rpc.FundingPayment.amount', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='injective_derivative_exchange_rpc.FundingPayment.timestamp', index=3,
      number=4, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5412,
  serialized_end=5505,
)


_FUNDINGRATESREQUEST = _descriptor.Descriptor(
  name='FundingRatesRequest',
  full_name='injective_derivative_exchange_rpc.FundingRatesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective_derivative_exchange_rpc.FundingRatesRequest.market_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='skip', full_name='injective_derivative_exchange_rpc.FundingRatesRequest.skip', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='limit', full_name='injective_derivative_exchange_rpc.FundingRatesRequest.limit', index=2,
      number=3, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_time', full_name='injective_derivative_exchange_rpc.FundingRatesRequest.end_time', index=3,
      number=4, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5507,
  serialized_end=5594,
)


_FUNDINGRATESRESPONSE = _descriptor.Descriptor(
  name='FundingRatesResponse',
  full_name='injective_derivative_exchange_rpc.FundingRatesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='funding_rates', full_name='injective_derivative_exchange_rpc.FundingRatesResponse.funding_rates', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='paging', full_name='injective_derivative_exchange_rpc.FundingRatesResponse.paging', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5597,
  serialized_end=5749,
)


_FUNDINGRATE = _descriptor.Descriptor(
  name='FundingRate',
  full_name='injective_derivative_exchange_rpc.FundingRate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective_derivative_exchange_rpc.FundingRate.market_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rate', full_name='injective_derivative_exchange_rpc.FundingRate.rate', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='injective_derivative_exchange_rpc.FundingRate.timestamp', index=2,
      number=3, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5751,
  serialized_end=5816,
)


_STREAMPOSITIONSREQUEST = _descriptor.Descriptor(
  name='StreamPositionsRequest',
  full_name='injective_derivative_exchange_rpc.StreamPositionsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subaccount_id', full_name='injective_derivative_exchange_rpc.StreamPositionsRequest.subaccount_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective_derivative_exchange_rpc.StreamPositionsRequest.market_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_ids', full_name='injective_derivative_exchange_rpc.StreamPositionsRequest.market_ids', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subaccount_ids', full_name='injective_derivative_exchange_rpc.StreamPositionsRequest.subaccount_ids', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5818,
  serialized_end=5928,
)


_STREAMPOSITIONSRESPONSE = _descriptor.Descriptor(
  name='StreamPositionsResponse',
  full_name='injective_derivative_exchange_rpc.StreamPositionsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='position', full_name='injective_derivative_exchange_rpc.StreamPositionsResponse.position', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='injective_derivative_exchange_rpc.StreamPositionsResponse.timestamp', index=1,
      number=2, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5930,
  serialized_end=6047,
)


_STREAMORDERSREQUEST = _descriptor.Descriptor(
  name='StreamOrdersRequest',
  full_name='injective_derivative_exchange_rpc.StreamOrdersRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective_derivative_exchange_rpc.StreamOrdersRequest.market_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order_side', full_name='injective_derivative_exchange_rpc.StreamOrdersRequest.order_side', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subaccount_id', full_name='injective_derivative_exchange_rpc.StreamOrdersRequest.subaccount_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='skip', full_name='injective_derivative_exchange_rpc.StreamOrdersRequest.skip', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='limit', full_name='injective_derivative_exchange_rpc.StreamOrdersRequest.limit', index=4,
      number=5, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_time', full_name='injective_derivative_exchange_rpc.StreamOrdersRequest.start_time', index=5,
      number=6, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_time', full_name='injective_derivative_exchange_rpc.StreamOrdersRequest.end_time', index=6,
      number=7, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_ids', full_name='injective_derivative_exchange_rpc.StreamOrdersRequest.market_ids', index=7,
      number=8, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_conditional', full_name='injective_derivative_exchange_rpc.StreamOrdersRequest.is_conditional', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order_type', full_name='injective_derivative_exchange_rpc.StreamOrdersRequest.order_type', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='include_inactive', full_name='injective_derivative_exchange_rpc.StreamOrdersRequest.include_inactive', index=10,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6050,
  serialized_end=6290,
)


_STREAMORDERSRESPONSE = _descriptor.Descriptor(
  name='StreamOrdersResponse',
  full_name='injective_derivative_exchange_rpc.StreamOrdersResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='order', full_name='injective_derivative_exchange_rpc.StreamOrdersResponse.order', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='operation_type', full_name='injective_derivative_exchange_rpc.StreamOrdersResponse.operation_type', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='injective_derivative_exchange_rpc.StreamOrdersResponse.timestamp', index=2,
      number=3, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6293,
  serialized_end=6430,
)


_TRADESREQUEST = _descriptor.Descriptor(
  name='TradesRequest',
  full_name='injective_derivative_exchange_rpc.TradesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective_derivative_exchange_rpc.TradesRequest.market_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='execution_side', full_name='injective_derivative_exchange_rpc.TradesRequest.execution_side', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='direction', full_name='injective_derivative_exchange_rpc.TradesRequest.direction', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subaccount_id', full_name='injective_derivative_exchange_rpc.TradesRequest.subaccount_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='skip', full_name='injective_derivative_exchange_rpc.TradesRequest.skip', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='limit', full_name='injective_derivative_exchange_rpc.TradesRequest.limit', index=5,
      number=6, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_time', full_name='injective_derivative_exchange_rpc.TradesRequest.start_time', index=6,
      number=7, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_time', full_name='injective_derivative_exchange_rpc.TradesRequest.end_time', index=7,
      number=8, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_ids', full_name='injective_derivative_exchange_rpc.TradesRequest.market_ids', index=8,
      number=9, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subaccount_ids', full_name='injective_derivative_exchange_rpc.TradesRequest.subaccount_ids', index=9,
      number=10, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='execution_types', full_name='injective_derivative_exchange_rpc.TradesRequest.execution_types', index=10,
      number=11, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6433,
  serialized_end=6669,
)


_TRADESRESPONSE = _descriptor.Descriptor(
  name='TradesResponse',
  full_name='injective_derivative_exchange_rpc.TradesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='trades', full_name='injective_derivative_exchange_rpc.TradesResponse.trades', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='paging', full_name='injective_derivative_exchange_rpc.TradesResponse.paging', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6672,
  serialized_end=6815,
)


_DERIVATIVETRADE = _descriptor.Descriptor(
  name='DerivativeTrade',
  full_name='injective_derivative_exchange_rpc.DerivativeTrade',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='order_hash', full_name='injective_derivative_exchange_rpc.DerivativeTrade.order_hash', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subaccount_id', full_name='injective_derivative_exchange_rpc.DerivativeTrade.subaccount_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective_derivative_exchange_rpc.DerivativeTrade.market_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trade_execution_type', full_name='injective_derivative_exchange_rpc.DerivativeTrade.trade_execution_type', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_liquidation', full_name='injective_derivative_exchange_rpc.DerivativeTrade.is_liquidation', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='position_delta', full_name='injective_derivative_exchange_rpc.DerivativeTrade.position_delta', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='payout', full_name='injective_derivative_exchange_rpc.DerivativeTrade.payout', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fee', full_name='injective_derivative_exchange_rpc.DerivativeTrade.fee', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='executed_at', full_name='injective_derivative_exchange_rpc.DerivativeTrade.executed_at', index=8,
      number=9, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fee_recipient', full_name='injective_derivative_exchange_rpc.DerivativeTrade.fee_recipient', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trade_id', full_name='injective_derivative_exchange_rpc.DerivativeTrade.trade_id', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6818,
  serialized_end=7116,
)


_POSITIONDELTA = _descriptor.Descriptor(
  name='PositionDelta',
  full_name='injective_derivative_exchange_rpc.PositionDelta',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='trade_direction', full_name='injective_derivative_exchange_rpc.PositionDelta.trade_direction', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='execution_price', full_name='injective_derivative_exchange_rpc.PositionDelta.execution_price', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='execution_quantity', full_name='injective_derivative_exchange_rpc.PositionDelta.execution_quantity', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='execution_margin', full_name='injective_derivative_exchange_rpc.PositionDelta.execution_margin', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7118,
  serialized_end=7237,
)


_STREAMTRADESREQUEST = _descriptor.Descriptor(
  name='StreamTradesRequest',
  full_name='injective_derivative_exchange_rpc.StreamTradesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective_derivative_exchange_rpc.StreamTradesRequest.market_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='execution_side', full_name='injective_derivative_exchange_rpc.StreamTradesRequest.execution_side', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='direction', full_name='injective_derivative_exchange_rpc.StreamTradesRequest.direction', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subaccount_id', full_name='injective_derivative_exchange_rpc.StreamTradesRequest.subaccount_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='skip', full_name='injective_derivative_exchange_rpc.StreamTradesRequest.skip', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='limit', full_name='injective_derivative_exchange_rpc.StreamTradesRequest.limit', index=5,
      number=6, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_time', full_name='injective_derivative_exchange_rpc.StreamTradesRequest.start_time', index=6,
      number=7, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_time', full_name='injective_derivative_exchange_rpc.StreamTradesRequest.end_time', index=7,
      number=8, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_ids', full_name='injective_derivative_exchange_rpc.StreamTradesRequest.market_ids', index=8,
      number=9, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subaccount_ids', full_name='injective_derivative_exchange_rpc.StreamTradesRequest.subaccount_ids', index=9,
      number=10, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='execution_types', full_name='injective_derivative_exchange_rpc.StreamTradesRequest.execution_types', index=10,
      number=11, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7240,
  serialized_end=7482,
)


_STREAMTRADESRESPONSE = _descriptor.Descriptor(
  name='StreamTradesResponse',
  full_name='injective_derivative_exchange_rpc.StreamTradesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='trade', full_name='injective_derivative_exchange_rpc.StreamTradesResponse.trade', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='operation_type', full_name='injective_derivative_exchange_rpc.StreamTradesResponse.operation_type', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='injective_derivative_exchange_rpc.StreamTradesResponse.timestamp', index=2,
      number=3, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7485,
  serialized_end=7617,
)


_SUBACCOUNTORDERSLISTREQUEST = _descriptor.Descriptor(
  name='SubaccountOrdersListRequest',
  full_name='injective_derivative_exchange_rpc.SubaccountOrdersListRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subaccount_id', full_name='injective_derivative_exchange_rpc.SubaccountOrdersListRequest.subaccount_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective_derivative_exchange_rpc.SubaccountOrdersListRequest.market_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='skip', full_name='injective_derivative_exchange_rpc.SubaccountOrdersListRequest.skip', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='limit', full_name='injective_derivative_exchange_rpc.SubaccountOrdersListRequest.limit', index=3,
      number=4, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7619,
  serialized_end=7719,
)


_SUBACCOUNTORDERSLISTRESPONSE = _descriptor.Descriptor(
  name='SubaccountOrdersListResponse',
  full_name='injective_derivative_exchange_rpc.SubaccountOrdersListResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='orders', full_name='injective_derivative_exchange_rpc.SubaccountOrdersListResponse.orders', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='paging', full_name='injective_derivative_exchange_rpc.SubaccountOrdersListResponse.paging', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7722,
  serialized_end=7884,
)


_SUBACCOUNTTRADESLISTREQUEST = _descriptor.Descriptor(
  name='SubaccountTradesListRequest',
  full_name='injective_derivative_exchange_rpc.SubaccountTradesListRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subaccount_id', full_name='injective_derivative_exchange_rpc.SubaccountTradesListRequest.subaccount_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective_derivative_exchange_rpc.SubaccountTradesListRequest.market_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='execution_type', full_name='injective_derivative_exchange_rpc.SubaccountTradesListRequest.execution_type', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='direction', full_name='injective_derivative_exchange_rpc.SubaccountTradesListRequest.direction', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='skip', full_name='injective_derivative_exchange_rpc.SubaccountTradesListRequest.skip', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='limit', full_name='injective_derivative_exchange_rpc.SubaccountTradesListRequest.limit', index=5,
      number=6, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7887,
  serialized_end=8030,
)


_SUBACCOUNTTRADESLISTRESPONSE = _descriptor.Descriptor(
  name='SubaccountTradesListResponse',
  full_name='injective_derivative_exchange_rpc.SubaccountTradesListResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='trades', full_name='injective_derivative_exchange_rpc.SubaccountTradesListResponse.trades', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8032,
  serialized_end=8130,
)


_ORDERSHISTORYREQUEST = _descriptor.Descriptor(
  name='OrdersHistoryRequest',
  full_name='injective_derivative_exchange_rpc.OrdersHistoryRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subaccount_id', full_name='injective_derivative_exchange_rpc.OrdersHistoryRequest.subaccount_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective_derivative_exchange_rpc.OrdersHistoryRequest.market_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='skip', full_name='injective_derivative_exchange_rpc.OrdersHistoryRequest.skip', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='limit', full_name='injective_derivative_exchange_rpc.OrdersHistoryRequest.limit', index=3,
      number=4, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order_types', full_name='injective_derivative_exchange_rpc.OrdersHistoryRequest.order_types', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='direction', full_name='injective_derivative_exchange_rpc.OrdersHistoryRequest.direction', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_time', full_name='injective_derivative_exchange_rpc.OrdersHistoryRequest.start_time', index=6,
      number=7, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_time', full_name='injective_derivative_exchange_rpc.OrdersHistoryRequest.end_time', index=7,
      number=8, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_conditional', full_name='injective_derivative_exchange_rpc.OrdersHistoryRequest.is_conditional', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='injective_derivative_exchange_rpc.OrdersHistoryRequest.state', index=9,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='execution_types', full_name='injective_derivative_exchange_rpc.OrdersHistoryRequest.execution_types', index=10,
      number=12, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8133,
  serialized_end=8368,
)


_ORDERSHISTORYRESPONSE = _descriptor.Descriptor(
  name='OrdersHistoryResponse',
  full_name='injective_derivative_exchange_rpc.OrdersHistoryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='orders', full_name='injective_derivative_exchange_rpc.OrdersHistoryResponse.orders', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='paging', full_name='injective_derivative_exchange_rpc.OrdersHistoryResponse.paging', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8371,
  serialized_end=8528,
)


_DERIVATIVEORDERHISTORY = _descriptor.Descriptor(
  name='DerivativeOrderHistory',
  full_name='injective_derivative_exchange_rpc.DerivativeOrderHistory',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='order_hash', full_name='injective_derivative_exchange_rpc.DerivativeOrderHistory.order_hash', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective_derivative_exchange_rpc.DerivativeOrderHistory.market_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_active', full_name='injective_derivative_exchange_rpc.DerivativeOrderHistory.is_active', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subaccount_id', full_name='injective_derivative_exchange_rpc.DerivativeOrderHistory.subaccount_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='execution_type', full_name='injective_derivative_exchange_rpc.DerivativeOrderHistory.execution_type', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order_type', full_name='injective_derivative_exchange_rpc.DerivativeOrderHistory.order_type', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='price', full_name='injective_derivative_exchange_rpc.DerivativeOrderHistory.price', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trigger_price', full_name='injective_derivative_exchange_rpc.DerivativeOrderHistory.trigger_price', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quantity', full_name='injective_derivative_exchange_rpc.DerivativeOrderHistory.quantity', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filled_quantity', full_name='injective_derivative_exchange_rpc.DerivativeOrderHistory.filled_quantity', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='injective_derivative_exchange_rpc.DerivativeOrderHistory.state', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='injective_derivative_exchange_rpc.DerivativeOrderHistory.created_at', index=11,
      number=12, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updated_at', full_name='injective_derivative_exchange_rpc.DerivativeOrderHistory.updated_at', index=12,
      number=13, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_reduce_only', full_name='injective_derivative_exchange_rpc.DerivativeOrderHistory.is_reduce_only', index=13,
      number=14, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='direction', full_name='injective_derivative_exchange_rpc.DerivativeOrderHistory.direction', index=14,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_conditional', full_name='injective_derivative_exchange_rpc.DerivativeOrderHistory.is_conditional', index=15,
      number=16, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trigger_at', full_name='injective_derivative_exchange_rpc.DerivativeOrderHistory.trigger_at', index=16,
      number=17, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='placed_order_hash', full_name='injective_derivative_exchange_rpc.DerivativeOrderHistory.placed_order_hash', index=17,
      number=18, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='margin', full_name='injective_derivative_exchange_rpc.DerivativeOrderHistory.margin', index=18,
      number=19, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8531,
  serialized_end=8946,
)


_STREAMORDERSHISTORYREQUEST = _descriptor.Descriptor(
  name='StreamOrdersHistoryRequest',
  full_name='injective_derivative_exchange_rpc.StreamOrdersHistoryRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subaccount_id', full_name='injective_derivative_exchange_rpc.StreamOrdersHistoryRequest.subaccount_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective_derivative_exchange_rpc.StreamOrdersHistoryRequest.market_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order_types', full_name='injective_derivative_exchange_rpc.StreamOrdersHistoryRequest.order_types', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='direction', full_name='injective_derivative_exchange_rpc.StreamOrdersHistoryRequest.direction', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='injective_derivative_exchange_rpc.StreamOrdersHistoryRequest.state', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='execution_types', full_name='injective_derivative_exchange_rpc.StreamOrdersHistoryRequest.execution_types', index=5,
      number=6, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8949,
  serialized_end=9099,
)


_STREAMORDERSHISTORYRESPONSE = _descriptor.Descriptor(
  name='StreamOrdersHistoryResponse',
  full_name='injective_derivative_exchange_rpc.StreamOrdersHistoryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='order', full_name='injective_derivative_exchange_rpc.StreamOrdersHistoryResponse.order', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='operation_type', full_name='injective_derivative_exchange_rpc.StreamOrdersHistoryResponse.operation_type', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='injective_derivative_exchange_rpc.StreamOrdersHistoryResponse.timestamp', index=2,
      number=3, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9102,
  serialized_end=9248,
)

_MARKETSRESPONSE.fields_by_name['markets'].message_type = _DERIVATIVEMARKETINFO
_DERIVATIVEMARKETINFO.fields_by_name['quote_token_meta'].message_type = _TOKENMETA
_DERIVATIVEMARKETINFO.fields_by_name['perpetual_market_info'].message_type = _PERPETUALMARKETINFO
_DERIVATIVEMARKETINFO.fields_by_name['perpetual_market_funding'].message_type = _PERPETUALMARKETFUNDING
_DERIVATIVEMARKETINFO.fields_by_name['expiry_futures_market_info'].message_type = _EXPIRYFUTURESMARKETINFO
_MARKETRESPONSE.fields_by_name['market'].message_type = _DERIVATIVEMARKETINFO
_STREAMMARKETRESPONSE.fields_by_name['market'].message_type = _DERIVATIVEMARKETINFO
_BINARYOPTIONSMARKETSRESPONSE.fields_by_name['markets'].message_type = _BINARYOPTIONSMARKETINFO
_BINARYOPTIONSMARKETINFO.fields_by_name['quote_token_meta'].message_type = _TOKENMETA
_BINARYOPTIONSMARKETRESPONSE.fields_by_name['market'].message_type = _BINARYOPTIONSMARKETINFO
_ORDERBOOKRESPONSE.fields_by_name['orderbook'].message_type = _DERIVATIVELIMITORDERBOOK
_DERIVATIVELIMITORDERBOOK.fields_by_name['buys'].message_type = _PRICELEVEL
_DERIVATIVELIMITORDERBOOK.fields_by_name['sells'].message_type = _PRICELEVEL
_ORDERBOOKSRESPONSE.fields_by_name['orderbooks'].message_type = _SINGLEDERIVATIVELIMITORDERBOOK
_SINGLEDERIVATIVELIMITORDERBOOK.fields_by_name['orderbook'].message_type = _DERIVATIVELIMITORDERBOOK
_STREAMORDERBOOKRESPONSE.fields_by_name['orderbook'].message_type = _DERIVATIVELIMITORDERBOOK
_ORDERSRESPONSE.fields_by_name['orders'].message_type = _DERIVATIVELIMITORDER
_ORDERSRESPONSE.fields_by_name['paging'].message_type = _PAGING
_POSITIONSRESPONSE.fields_by_name['positions'].message_type = _DERIVATIVEPOSITION
_POSITIONSRESPONSE.fields_by_name['paging'].message_type = _PAGING
_LIQUIDABLEPOSITIONSRESPONSE.fields_by_name['positions'].message_type = _DERIVATIVEPOSITION
_FUNDINGPAYMENTSRESPONSE.fields_by_name['payments'].message_type = _FUNDINGPAYMENT
_FUNDINGPAYMENTSRESPONSE.fields_by_name['paging'].message_type = _PAGING
_FUNDINGRATESRESPONSE.fields_by_name['funding_rates'].message_type = _FUNDINGRATE
_FUNDINGRATESRESPONSE.fields_by_name['paging'].message_type = _PAGING
_STREAMPOSITIONSRESPONSE.fields_by_name['position'].message_type = _DERIVATIVEPOSITION
_STREAMORDERSRESPONSE.fields_by_name['order'].message_type = _DERIVATIVELIMITORDER
_TRADESRESPONSE.fields_by_name['trades'].message_type = _DERIVATIVETRADE
_TRADESRESPONSE.fields_by_name['paging'].message_type = _PAGING
_DERIVATIVETRADE.fields_by_name['position_delta'].message_type = _POSITIONDELTA
_STREAMTRADESRESPONSE.fields_by_name['trade'].message_type = _DERIVATIVETRADE
_SUBACCOUNTORDERSLISTRESPONSE.fields_by_name['orders'].message_type = _DERIVATIVELIMITORDER
_SUBACCOUNTORDERSLISTRESPONSE.fields_by_name['paging'].message_type = _PAGING
_SUBACCOUNTTRADESLISTRESPONSE.fields_by_name['trades'].message_type = _DERIVATIVETRADE
_ORDERSHISTORYRESPONSE.fields_by_name['orders'].message_type = _DERIVATIVEORDERHISTORY
_ORDERSHISTORYRESPONSE.fields_by_name['paging'].message_type = _PAGING
_STREAMORDERSHISTORYRESPONSE.fields_by_name['order'].message_type = _DERIVATIVEORDERHISTORY
DESCRIPTOR.message_types_by_name['MarketsRequest'] = _MARKETSREQUEST
DESCRIPTOR.message_types_by_name['MarketsResponse'] = _MARKETSRESPONSE
DESCRIPTOR.message_types_by_name['DerivativeMarketInfo'] = _DERIVATIVEMARKETINFO
DESCRIPTOR.message_types_by_name['TokenMeta'] = _TOKENMETA
DESCRIPTOR.message_types_by_name['PerpetualMarketInfo'] = _PERPETUALMARKETINFO
DESCRIPTOR.message_types_by_name['PerpetualMarketFunding'] = _PERPETUALMARKETFUNDING
DESCRIPTOR.message_types_by_name['ExpiryFuturesMarketInfo'] = _EXPIRYFUTURESMARKETINFO
DESCRIPTOR.message_types_by_name['MarketRequest'] = _MARKETREQUEST
DESCRIPTOR.message_types_by_name['MarketResponse'] = _MARKETRESPONSE
DESCRIPTOR.message_types_by_name['StreamMarketRequest'] = _STREAMMARKETREQUEST
DESCRIPTOR.message_types_by_name['StreamMarketResponse'] = _STREAMMARKETRESPONSE
DESCRIPTOR.message_types_by_name['BinaryOptionsMarketsRequest'] = _BINARYOPTIONSMARKETSREQUEST
DESCRIPTOR.message_types_by_name['BinaryOptionsMarketsResponse'] = _BINARYOPTIONSMARKETSRESPONSE
DESCRIPTOR.message_types_by_name['BinaryOptionsMarketInfo'] = _BINARYOPTIONSMARKETINFO
DESCRIPTOR.message_types_by_name['BinaryOptionsMarketRequest'] = _BINARYOPTIONSMARKETREQUEST
DESCRIPTOR.message_types_by_name['BinaryOptionsMarketResponse'] = _BINARYOPTIONSMARKETRESPONSE
DESCRIPTOR.message_types_by_name['OrderbookRequest'] = _ORDERBOOKREQUEST
DESCRIPTOR.message_types_by_name['OrderbookResponse'] = _ORDERBOOKRESPONSE
DESCRIPTOR.message_types_by_name['DerivativeLimitOrderbook'] = _DERIVATIVELIMITORDERBOOK
DESCRIPTOR.message_types_by_name['PriceLevel'] = _PRICELEVEL
DESCRIPTOR.message_types_by_name['OrderbooksRequest'] = _ORDERBOOKSREQUEST
DESCRIPTOR.message_types_by_name['OrderbooksResponse'] = _ORDERBOOKSRESPONSE
DESCRIPTOR.message_types_by_name['SingleDerivativeLimitOrderbook'] = _SINGLEDERIVATIVELIMITORDERBOOK
DESCRIPTOR.message_types_by_name['StreamOrderbookRequest'] = _STREAMORDERBOOKREQUEST
DESCRIPTOR.message_types_by_name['StreamOrderbookResponse'] = _STREAMORDERBOOKRESPONSE
DESCRIPTOR.message_types_by_name['OrdersRequest'] = _ORDERSREQUEST
DESCRIPTOR.message_types_by_name['OrdersResponse'] = _ORDERSRESPONSE
DESCRIPTOR.message_types_by_name['DerivativeLimitOrder'] = _DERIVATIVELIMITORDER
DESCRIPTOR.message_types_by_name['Paging'] = _PAGING
DESCRIPTOR.message_types_by_name['PositionsRequest'] = _POSITIONSREQUEST
DESCRIPTOR.message_types_by_name['PositionsResponse'] = _POSITIONSRESPONSE
DESCRIPTOR.message_types_by_name['DerivativePosition'] = _DERIVATIVEPOSITION
DESCRIPTOR.message_types_by_name['LiquidablePositionsRequest'] = _LIQUIDABLEPOSITIONSREQUEST
DESCRIPTOR.message_types_by_name['LiquidablePositionsResponse'] = _LIQUIDABLEPOSITIONSRESPONSE
DESCRIPTOR.message_types_by_name['FundingPaymentsRequest'] = _FUNDINGPAYMENTSREQUEST
DESCRIPTOR.message_types_by_name['FundingPaymentsResponse'] = _FUNDINGPAYMENTSRESPONSE
DESCRIPTOR.message_types_by_name['FundingPayment'] = _FUNDINGPAYMENT
DESCRIPTOR.message_types_by_name['FundingRatesRequest'] = _FUNDINGRATESREQUEST
DESCRIPTOR.message_types_by_name['FundingRatesResponse'] = _FUNDINGRATESRESPONSE
DESCRIPTOR.message_types_by_name['FundingRate'] = _FUNDINGRATE
DESCRIPTOR.message_types_by_name['StreamPositionsRequest'] = _STREAMPOSITIONSREQUEST
DESCRIPTOR.message_types_by_name['StreamPositionsResponse'] = _STREAMPOSITIONSRESPONSE
DESCRIPTOR.message_types_by_name['StreamOrdersRequest'] = _STREAMORDERSREQUEST
DESCRIPTOR.message_types_by_name['StreamOrdersResponse'] = _STREAMORDERSRESPONSE
DESCRIPTOR.message_types_by_name['TradesRequest'] = _TRADESREQUEST
DESCRIPTOR.message_types_by_name['TradesResponse'] = _TRADESRESPONSE
DESCRIPTOR.message_types_by_name['DerivativeTrade'] = _DERIVATIVETRADE
DESCRIPTOR.message_types_by_name['PositionDelta'] = _POSITIONDELTA
DESCRIPTOR.message_types_by_name['StreamTradesRequest'] = _STREAMTRADESREQUEST
DESCRIPTOR.message_types_by_name['StreamTradesResponse'] = _STREAMTRADESRESPONSE
DESCRIPTOR.message_types_by_name['SubaccountOrdersListRequest'] = _SUBACCOUNTORDERSLISTREQUEST
DESCRIPTOR.message_types_by_name['SubaccountOrdersListResponse'] = _SUBACCOUNTORDERSLISTRESPONSE
DESCRIPTOR.message_types_by_name['SubaccountTradesListRequest'] = _SUBACCOUNTTRADESLISTREQUEST
DESCRIPTOR.message_types_by_name['SubaccountTradesListResponse'] = _SUBACCOUNTTRADESLISTRESPONSE
DESCRIPTOR.message_types_by_name['OrdersHistoryRequest'] = _ORDERSHISTORYREQUEST
DESCRIPTOR.message_types_by_name['OrdersHistoryResponse'] = _ORDERSHISTORYRESPONSE
DESCRIPTOR.message_types_by_name['DerivativeOrderHistory'] = _DERIVATIVEORDERHISTORY
DESCRIPTOR.message_types_by_name['StreamOrdersHistoryRequest'] = _STREAMORDERSHISTORYREQUEST
DESCRIPTOR.message_types_by_name['StreamOrdersHistoryResponse'] = _STREAMORDERSHISTORYRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MarketsRequest = _reflection.GeneratedProtocolMessageType('MarketsRequest', (_message.Message,), {
  'DESCRIPTOR' : _MARKETSREQUEST,
  '__module__' : 'exchange.injective_derivative_exchange_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_derivative_exchange_rpc.MarketsRequest)
  })
_sym_db.RegisterMessage(MarketsRequest)

MarketsResponse = _reflection.GeneratedProtocolMessageType('MarketsResponse', (_message.Message,), {
  'DESCRIPTOR' : _MARKETSRESPONSE,
  '__module__' : 'exchange.injective_derivative_exchange_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_derivative_exchange_rpc.MarketsResponse)
  })
_sym_db.RegisterMessage(MarketsResponse)

DerivativeMarketInfo = _reflection.GeneratedProtocolMessageType('DerivativeMarketInfo', (_message.Message,), {
  'DESCRIPTOR' : _DERIVATIVEMARKETINFO,
  '__module__' : 'exchange.injective_derivative_exchange_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_derivative_exchange_rpc.DerivativeMarketInfo)
  })
_sym_db.RegisterMessage(DerivativeMarketInfo)

TokenMeta = _reflection.GeneratedProtocolMessageType('TokenMeta', (_message.Message,), {
  'DESCRIPTOR' : _TOKENMETA,
  '__module__' : 'exchange.injective_derivative_exchange_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_derivative_exchange_rpc.TokenMeta)
  })
_sym_db.RegisterMessage(TokenMeta)

PerpetualMarketInfo = _reflection.GeneratedProtocolMessageType('PerpetualMarketInfo', (_message.Message,), {
  'DESCRIPTOR' : _PERPETUALMARKETINFO,
  '__module__' : 'exchange.injective_derivative_exchange_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_derivative_exchange_rpc.PerpetualMarketInfo)
  })
_sym_db.RegisterMessage(PerpetualMarketInfo)

PerpetualMarketFunding = _reflection.GeneratedProtocolMessageType('PerpetualMarketFunding', (_message.Message,), {
  'DESCRIPTOR' : _PERPETUALMARKETFUNDING,
  '__module__' : 'exchange.injective_derivative_exchange_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_derivative_exchange_rpc.PerpetualMarketFunding)
  })
_sym_db.RegisterMessage(PerpetualMarketFunding)

ExpiryFuturesMarketInfo = _reflection.GeneratedProtocolMessageType('ExpiryFuturesMarketInfo', (_message.Message,), {
  'DESCRIPTOR' : _EXPIRYFUTURESMARKETINFO,
  '__module__' : 'exchange.injective_derivative_exchange_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_derivative_exchange_rpc.ExpiryFuturesMarketInfo)
  })
_sym_db.RegisterMessage(ExpiryFuturesMarketInfo)

MarketRequest = _reflection.GeneratedProtocolMessageType('MarketRequest', (_message.Message,), {
  'DESCRIPTOR' : _MARKETREQUEST,
  '__module__' : 'exchange.injective_derivative_exchange_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_derivative_exchange_rpc.MarketRequest)
  })
_sym_db.RegisterMessage(MarketRequest)

MarketResponse = _reflection.GeneratedProtocolMessageType('MarketResponse', (_message.Message,), {
  'DESCRIPTOR' : _MARKETRESPONSE,
  '__module__' : 'exchange.injective_derivative_exchange_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_derivative_exchange_rpc.MarketResponse)
  })
_sym_db.RegisterMessage(MarketResponse)

StreamMarketRequest = _reflection.GeneratedProtocolMessageType('StreamMarketRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMMARKETREQUEST,
  '__module__' : 'exchange.injective_derivative_exchange_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_derivative_exchange_rpc.StreamMarketRequest)
  })
_sym_db.RegisterMessage(StreamMarketRequest)

StreamMarketResponse = _reflection.GeneratedProtocolMessageType('StreamMarketResponse', (_message.Message,), {
  'DESCRIPTOR' : _STREAMMARKETRESPONSE,
  '__module__' : 'exchange.injective_derivative_exchange_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_derivative_exchange_rpc.StreamMarketResponse)
  })
_sym_db.RegisterMessage(StreamMarketResponse)

BinaryOptionsMarketsRequest = _reflection.GeneratedProtocolMessageType('BinaryOptionsMarketsRequest', (_message.Message,), {
  'DESCRIPTOR' : _BINARYOPTIONSMARKETSREQUEST,
  '__module__' : 'exchange.injective_derivative_exchange_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_derivative_exchange_rpc.BinaryOptionsMarketsRequest)
  })
_sym_db.RegisterMessage(BinaryOptionsMarketsRequest)

BinaryOptionsMarketsResponse = _reflection.GeneratedProtocolMessageType('BinaryOptionsMarketsResponse', (_message.Message,), {
  'DESCRIPTOR' : _BINARYOPTIONSMARKETSRESPONSE,
  '__module__' : 'exchange.injective_derivative_exchange_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_derivative_exchange_rpc.BinaryOptionsMarketsResponse)
  })
_sym_db.RegisterMessage(BinaryOptionsMarketsResponse)

BinaryOptionsMarketInfo = _reflection.GeneratedProtocolMessageType('BinaryOptionsMarketInfo', (_message.Message,), {
  'DESCRIPTOR' : _BINARYOPTIONSMARKETINFO,
  '__module__' : 'exchange.injective_derivative_exchange_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_derivative_exchange_rpc.BinaryOptionsMarketInfo)
  })
_sym_db.RegisterMessage(BinaryOptionsMarketInfo)

BinaryOptionsMarketRequest = _reflection.GeneratedProtocolMessageType('BinaryOptionsMarketRequest', (_message.Message,), {
  'DESCRIPTOR' : _BINARYOPTIONSMARKETREQUEST,
  '__module__' : 'exchange.injective_derivative_exchange_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_derivative_exchange_rpc.BinaryOptionsMarketRequest)
  })
_sym_db.RegisterMessage(BinaryOptionsMarketRequest)

BinaryOptionsMarketResponse = _reflection.GeneratedProtocolMessageType('BinaryOptionsMarketResponse', (_message.Message,), {
  'DESCRIPTOR' : _BINARYOPTIONSMARKETRESPONSE,
  '__module__' : 'exchange.injective_derivative_exchange_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_derivative_exchange_rpc.BinaryOptionsMarketResponse)
  })
_sym_db.RegisterMessage(BinaryOptionsMarketResponse)

OrderbookRequest = _reflection.GeneratedProtocolMessageType('OrderbookRequest', (_message.Message,), {
  'DESCRIPTOR' : _ORDERBOOKREQUEST,
  '__module__' : 'exchange.injective_derivative_exchange_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_derivative_exchange_rpc.OrderbookRequest)
  })
_sym_db.RegisterMessage(OrderbookRequest)

OrderbookResponse = _reflection.GeneratedProtocolMessageType('OrderbookResponse', (_message.Message,), {
  'DESCRIPTOR' : _ORDERBOOKRESPONSE,
  '__module__' : 'exchange.injective_derivative_exchange_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_derivative_exchange_rpc.OrderbookResponse)
  })
_sym_db.RegisterMessage(OrderbookResponse)

DerivativeLimitOrderbook = _reflection.GeneratedProtocolMessageType('DerivativeLimitOrderbook', (_message.Message,), {
  'DESCRIPTOR' : _DERIVATIVELIMITORDERBOOK,
  '__module__' : 'exchange.injective_derivative_exchange_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_derivative_exchange_rpc.DerivativeLimitOrderbook)
  })
_sym_db.RegisterMessage(DerivativeLimitOrderbook)

PriceLevel = _reflection.GeneratedProtocolMessageType('PriceLevel', (_message.Message,), {
  'DESCRIPTOR' : _PRICELEVEL,
  '__module__' : 'exchange.injective_derivative_exchange_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_derivative_exchange_rpc.PriceLevel)
  })
_sym_db.RegisterMessage(PriceLevel)

OrderbooksRequest = _reflection.GeneratedProtocolMessageType('OrderbooksRequest', (_message.Message,), {
  'DESCRIPTOR' : _ORDERBOOKSREQUEST,
  '__module__' : 'exchange.injective_derivative_exchange_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_derivative_exchange_rpc.OrderbooksRequest)
  })
_sym_db.RegisterMessage(OrderbooksRequest)

OrderbooksResponse = _reflection.GeneratedProtocolMessageType('OrderbooksResponse', (_message.Message,), {
  'DESCRIPTOR' : _ORDERBOOKSRESPONSE,
  '__module__' : 'exchange.injective_derivative_exchange_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_derivative_exchange_rpc.OrderbooksResponse)
  })
_sym_db.RegisterMessage(OrderbooksResponse)

SingleDerivativeLimitOrderbook = _reflection.GeneratedProtocolMessageType('SingleDerivativeLimitOrderbook', (_message.Message,), {
  'DESCRIPTOR' : _SINGLEDERIVATIVELIMITORDERBOOK,
  '__module__' : 'exchange.injective_derivative_exchange_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_derivative_exchange_rpc.SingleDerivativeLimitOrderbook)
  })
_sym_db.RegisterMessage(SingleDerivativeLimitOrderbook)

StreamOrderbookRequest = _reflection.GeneratedProtocolMessageType('StreamOrderbookRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMORDERBOOKREQUEST,
  '__module__' : 'exchange.injective_derivative_exchange_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_derivative_exchange_rpc.StreamOrderbookRequest)
  })
_sym_db.RegisterMessage(StreamOrderbookRequest)

StreamOrderbookResponse = _reflection.GeneratedProtocolMessageType('StreamOrderbookResponse', (_message.Message,), {
  'DESCRIPTOR' : _STREAMORDERBOOKRESPONSE,
  '__module__' : 'exchange.injective_derivative_exchange_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_derivative_exchange_rpc.StreamOrderbookResponse)
  })
_sym_db.RegisterMessage(StreamOrderbookResponse)

OrdersRequest = _reflection.GeneratedProtocolMessageType('OrdersRequest', (_message.Message,), {
  'DESCRIPTOR' : _ORDERSREQUEST,
  '__module__' : 'exchange.injective_derivative_exchange_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_derivative_exchange_rpc.OrdersRequest)
  })
_sym_db.RegisterMessage(OrdersRequest)

OrdersResponse = _reflection.GeneratedProtocolMessageType('OrdersResponse', (_message.Message,), {
  'DESCRIPTOR' : _ORDERSRESPONSE,
  '__module__' : 'exchange.injective_derivative_exchange_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_derivative_exchange_rpc.OrdersResponse)
  })
_sym_db.RegisterMessage(OrdersResponse)

DerivativeLimitOrder = _reflection.GeneratedProtocolMessageType('DerivativeLimitOrder', (_message.Message,), {
  'DESCRIPTOR' : _DERIVATIVELIMITORDER,
  '__module__' : 'exchange.injective_derivative_exchange_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_derivative_exchange_rpc.DerivativeLimitOrder)
  })
_sym_db.RegisterMessage(DerivativeLimitOrder)

Paging = _reflection.GeneratedProtocolMessageType('Paging', (_message.Message,), {
  'DESCRIPTOR' : _PAGING,
  '__module__' : 'exchange.injective_derivative_exchange_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_derivative_exchange_rpc.Paging)
  })
_sym_db.RegisterMessage(Paging)

PositionsRequest = _reflection.GeneratedProtocolMessageType('PositionsRequest', (_message.Message,), {
  'DESCRIPTOR' : _POSITIONSREQUEST,
  '__module__' : 'exchange.injective_derivative_exchange_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_derivative_exchange_rpc.PositionsRequest)
  })
_sym_db.RegisterMessage(PositionsRequest)

PositionsResponse = _reflection.GeneratedProtocolMessageType('PositionsResponse', (_message.Message,), {
  'DESCRIPTOR' : _POSITIONSRESPONSE,
  '__module__' : 'exchange.injective_derivative_exchange_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_derivative_exchange_rpc.PositionsResponse)
  })
_sym_db.RegisterMessage(PositionsResponse)

DerivativePosition = _reflection.GeneratedProtocolMessageType('DerivativePosition', (_message.Message,), {
  'DESCRIPTOR' : _DERIVATIVEPOSITION,
  '__module__' : 'exchange.injective_derivative_exchange_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_derivative_exchange_rpc.DerivativePosition)
  })
_sym_db.RegisterMessage(DerivativePosition)

LiquidablePositionsRequest = _reflection.GeneratedProtocolMessageType('LiquidablePositionsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LIQUIDABLEPOSITIONSREQUEST,
  '__module__' : 'exchange.injective_derivative_exchange_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_derivative_exchange_rpc.LiquidablePositionsRequest)
  })
_sym_db.RegisterMessage(LiquidablePositionsRequest)

LiquidablePositionsResponse = _reflection.GeneratedProtocolMessageType('LiquidablePositionsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LIQUIDABLEPOSITIONSRESPONSE,
  '__module__' : 'exchange.injective_derivative_exchange_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_derivative_exchange_rpc.LiquidablePositionsResponse)
  })
_sym_db.RegisterMessage(LiquidablePositionsResponse)

FundingPaymentsRequest = _reflection.GeneratedProtocolMessageType('FundingPaymentsRequest', (_message.Message,), {
  'DESCRIPTOR' : _FUNDINGPAYMENTSREQUEST,
  '__module__' : 'exchange.injective_derivative_exchange_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_derivative_exchange_rpc.FundingPaymentsRequest)
  })
_sym_db.RegisterMessage(FundingPaymentsRequest)

FundingPaymentsResponse = _reflection.GeneratedProtocolMessageType('FundingPaymentsResponse', (_message.Message,), {
  'DESCRIPTOR' : _FUNDINGPAYMENTSRESPONSE,
  '__module__' : 'exchange.injective_derivative_exchange_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_derivative_exchange_rpc.FundingPaymentsResponse)
  })
_sym_db.RegisterMessage(FundingPaymentsResponse)

FundingPayment = _reflection.GeneratedProtocolMessageType('FundingPayment', (_message.Message,), {
  'DESCRIPTOR' : _FUNDINGPAYMENT,
  '__module__' : 'exchange.injective_derivative_exchange_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_derivative_exchange_rpc.FundingPayment)
  })
_sym_db.RegisterMessage(FundingPayment)

FundingRatesRequest = _reflection.GeneratedProtocolMessageType('FundingRatesRequest', (_message.Message,), {
  'DESCRIPTOR' : _FUNDINGRATESREQUEST,
  '__module__' : 'exchange.injective_derivative_exchange_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_derivative_exchange_rpc.FundingRatesRequest)
  })
_sym_db.RegisterMessage(FundingRatesRequest)

FundingRatesResponse = _reflection.GeneratedProtocolMessageType('FundingRatesResponse', (_message.Message,), {
  'DESCRIPTOR' : _FUNDINGRATESRESPONSE,
  '__module__' : 'exchange.injective_derivative_exchange_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_derivative_exchange_rpc.FundingRatesResponse)
  })
_sym_db.RegisterMessage(FundingRatesResponse)

FundingRate = _reflection.GeneratedProtocolMessageType('FundingRate', (_message.Message,), {
  'DESCRIPTOR' : _FUNDINGRATE,
  '__module__' : 'exchange.injective_derivative_exchange_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_derivative_exchange_rpc.FundingRate)
  })
_sym_db.RegisterMessage(FundingRate)

StreamPositionsRequest = _reflection.GeneratedProtocolMessageType('StreamPositionsRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMPOSITIONSREQUEST,
  '__module__' : 'exchange.injective_derivative_exchange_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_derivative_exchange_rpc.StreamPositionsRequest)
  })
_sym_db.RegisterMessage(StreamPositionsRequest)

StreamPositionsResponse = _reflection.GeneratedProtocolMessageType('StreamPositionsResponse', (_message.Message,), {
  'DESCRIPTOR' : _STREAMPOSITIONSRESPONSE,
  '__module__' : 'exchange.injective_derivative_exchange_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_derivative_exchange_rpc.StreamPositionsResponse)
  })
_sym_db.RegisterMessage(StreamPositionsResponse)

StreamOrdersRequest = _reflection.GeneratedProtocolMessageType('StreamOrdersRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMORDERSREQUEST,
  '__module__' : 'exchange.injective_derivative_exchange_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_derivative_exchange_rpc.StreamOrdersRequest)
  })
_sym_db.RegisterMessage(StreamOrdersRequest)

StreamOrdersResponse = _reflection.GeneratedProtocolMessageType('StreamOrdersResponse', (_message.Message,), {
  'DESCRIPTOR' : _STREAMORDERSRESPONSE,
  '__module__' : 'exchange.injective_derivative_exchange_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_derivative_exchange_rpc.StreamOrdersResponse)
  })
_sym_db.RegisterMessage(StreamOrdersResponse)

TradesRequest = _reflection.GeneratedProtocolMessageType('TradesRequest', (_message.Message,), {
  'DESCRIPTOR' : _TRADESREQUEST,
  '__module__' : 'exchange.injective_derivative_exchange_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_derivative_exchange_rpc.TradesRequest)
  })
_sym_db.RegisterMessage(TradesRequest)

TradesResponse = _reflection.GeneratedProtocolMessageType('TradesResponse', (_message.Message,), {
  'DESCRIPTOR' : _TRADESRESPONSE,
  '__module__' : 'exchange.injective_derivative_exchange_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_derivative_exchange_rpc.TradesResponse)
  })
_sym_db.RegisterMessage(TradesResponse)

DerivativeTrade = _reflection.GeneratedProtocolMessageType('DerivativeTrade', (_message.Message,), {
  'DESCRIPTOR' : _DERIVATIVETRADE,
  '__module__' : 'exchange.injective_derivative_exchange_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_derivative_exchange_rpc.DerivativeTrade)
  })
_sym_db.RegisterMessage(DerivativeTrade)

PositionDelta = _reflection.GeneratedProtocolMessageType('PositionDelta', (_message.Message,), {
  'DESCRIPTOR' : _POSITIONDELTA,
  '__module__' : 'exchange.injective_derivative_exchange_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_derivative_exchange_rpc.PositionDelta)
  })
_sym_db.RegisterMessage(PositionDelta)

StreamTradesRequest = _reflection.GeneratedProtocolMessageType('StreamTradesRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMTRADESREQUEST,
  '__module__' : 'exchange.injective_derivative_exchange_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_derivative_exchange_rpc.StreamTradesRequest)
  })
_sym_db.RegisterMessage(StreamTradesRequest)

StreamTradesResponse = _reflection.GeneratedProtocolMessageType('StreamTradesResponse', (_message.Message,), {
  'DESCRIPTOR' : _STREAMTRADESRESPONSE,
  '__module__' : 'exchange.injective_derivative_exchange_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_derivative_exchange_rpc.StreamTradesResponse)
  })
_sym_db.RegisterMessage(StreamTradesResponse)

SubaccountOrdersListRequest = _reflection.GeneratedProtocolMessageType('SubaccountOrdersListRequest', (_message.Message,), {
  'DESCRIPTOR' : _SUBACCOUNTORDERSLISTREQUEST,
  '__module__' : 'exchange.injective_derivative_exchange_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_derivative_exchange_rpc.SubaccountOrdersListRequest)
  })
_sym_db.RegisterMessage(SubaccountOrdersListRequest)

SubaccountOrdersListResponse = _reflection.GeneratedProtocolMessageType('SubaccountOrdersListResponse', (_message.Message,), {
  'DESCRIPTOR' : _SUBACCOUNTORDERSLISTRESPONSE,
  '__module__' : 'exchange.injective_derivative_exchange_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_derivative_exchange_rpc.SubaccountOrdersListResponse)
  })
_sym_db.RegisterMessage(SubaccountOrdersListResponse)

SubaccountTradesListRequest = _reflection.GeneratedProtocolMessageType('SubaccountTradesListRequest', (_message.Message,), {
  'DESCRIPTOR' : _SUBACCOUNTTRADESLISTREQUEST,
  '__module__' : 'exchange.injective_derivative_exchange_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_derivative_exchange_rpc.SubaccountTradesListRequest)
  })
_sym_db.RegisterMessage(SubaccountTradesListRequest)

SubaccountTradesListResponse = _reflection.GeneratedProtocolMessageType('SubaccountTradesListResponse', (_message.Message,), {
  'DESCRIPTOR' : _SUBACCOUNTTRADESLISTRESPONSE,
  '__module__' : 'exchange.injective_derivative_exchange_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_derivative_exchange_rpc.SubaccountTradesListResponse)
  })
_sym_db.RegisterMessage(SubaccountTradesListResponse)

OrdersHistoryRequest = _reflection.GeneratedProtocolMessageType('OrdersHistoryRequest', (_message.Message,), {
  'DESCRIPTOR' : _ORDERSHISTORYREQUEST,
  '__module__' : 'exchange.injective_derivative_exchange_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_derivative_exchange_rpc.OrdersHistoryRequest)
  })
_sym_db.RegisterMessage(OrdersHistoryRequest)

OrdersHistoryResponse = _reflection.GeneratedProtocolMessageType('OrdersHistoryResponse', (_message.Message,), {
  'DESCRIPTOR' : _ORDERSHISTORYRESPONSE,
  '__module__' : 'exchange.injective_derivative_exchange_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_derivative_exchange_rpc.OrdersHistoryResponse)
  })
_sym_db.RegisterMessage(OrdersHistoryResponse)

DerivativeOrderHistory = _reflection.GeneratedProtocolMessageType('DerivativeOrderHistory', (_message.Message,), {
  'DESCRIPTOR' : _DERIVATIVEORDERHISTORY,
  '__module__' : 'exchange.injective_derivative_exchange_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_derivative_exchange_rpc.DerivativeOrderHistory)
  })
_sym_db.RegisterMessage(DerivativeOrderHistory)

StreamOrdersHistoryRequest = _reflection.GeneratedProtocolMessageType('StreamOrdersHistoryRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMORDERSHISTORYREQUEST,
  '__module__' : 'exchange.injective_derivative_exchange_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_derivative_exchange_rpc.StreamOrdersHistoryRequest)
  })
_sym_db.RegisterMessage(StreamOrdersHistoryRequest)

StreamOrdersHistoryResponse = _reflection.GeneratedProtocolMessageType('StreamOrdersHistoryResponse', (_message.Message,), {
  'DESCRIPTOR' : _STREAMORDERSHISTORYRESPONSE,
  '__module__' : 'exchange.injective_derivative_exchange_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_derivative_exchange_rpc.StreamOrdersHistoryResponse)
  })
_sym_db.RegisterMessage(StreamOrdersHistoryResponse)


DESCRIPTOR._options = None

_INJECTIVEDERIVATIVEEXCHANGERPC = _descriptor.ServiceDescriptor(
  name='InjectiveDerivativeExchangeRPC',
  full_name='injective_derivative_exchange_rpc.InjectiveDerivativeExchangeRPC',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=9251,
  serialized_end=12089,
  methods=[
  _descriptor.MethodDescriptor(
    name='Markets',
    full_name='injective_derivative_exchange_rpc.InjectiveDerivativeExchangeRPC.Markets',
    index=0,
    containing_service=None,
    input_type=_MARKETSREQUEST,
    output_type=_MARKETSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Market',
    full_name='injective_derivative_exchange_rpc.InjectiveDerivativeExchangeRPC.Market',
    index=1,
    containing_service=None,
    input_type=_MARKETREQUEST,
    output_type=_MARKETRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StreamMarket',
    full_name='injective_derivative_exchange_rpc.InjectiveDerivativeExchangeRPC.StreamMarket',
    index=2,
    containing_service=None,
    input_type=_STREAMMARKETREQUEST,
    output_type=_STREAMMARKETRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='BinaryOptionsMarkets',
    full_name='injective_derivative_exchange_rpc.InjectiveDerivativeExchangeRPC.BinaryOptionsMarkets',
    index=3,
    containing_service=None,
    input_type=_BINARYOPTIONSMARKETSREQUEST,
    output_type=_BINARYOPTIONSMARKETSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='BinaryOptionsMarket',
    full_name='injective_derivative_exchange_rpc.InjectiveDerivativeExchangeRPC.BinaryOptionsMarket',
    index=4,
    containing_service=None,
    input_type=_BINARYOPTIONSMARKETREQUEST,
    output_type=_BINARYOPTIONSMARKETRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Orderbook',
    full_name='injective_derivative_exchange_rpc.InjectiveDerivativeExchangeRPC.Orderbook',
    index=5,
    containing_service=None,
    input_type=_ORDERBOOKREQUEST,
    output_type=_ORDERBOOKRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Orderbooks',
    full_name='injective_derivative_exchange_rpc.InjectiveDerivativeExchangeRPC.Orderbooks',
    index=6,
    containing_service=None,
    input_type=_ORDERBOOKSREQUEST,
    output_type=_ORDERBOOKSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StreamOrderbook',
    full_name='injective_derivative_exchange_rpc.InjectiveDerivativeExchangeRPC.StreamOrderbook',
    index=7,
    containing_service=None,
    input_type=_STREAMORDERBOOKREQUEST,
    output_type=_STREAMORDERBOOKRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Orders',
    full_name='injective_derivative_exchange_rpc.InjectiveDerivativeExchangeRPC.Orders',
    index=8,
    containing_service=None,
    input_type=_ORDERSREQUEST,
    output_type=_ORDERSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Positions',
    full_name='injective_derivative_exchange_rpc.InjectiveDerivativeExchangeRPC.Positions',
    index=9,
    containing_service=None,
    input_type=_POSITIONSREQUEST,
    output_type=_POSITIONSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='LiquidablePositions',
    full_name='injective_derivative_exchange_rpc.InjectiveDerivativeExchangeRPC.LiquidablePositions',
    index=10,
    containing_service=None,
    input_type=_LIQUIDABLEPOSITIONSREQUEST,
    output_type=_LIQUIDABLEPOSITIONSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='FundingPayments',
    full_name='injective_derivative_exchange_rpc.InjectiveDerivativeExchangeRPC.FundingPayments',
    index=11,
    containing_service=None,
    input_type=_FUNDINGPAYMENTSREQUEST,
    output_type=_FUNDINGPAYMENTSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='FundingRates',
    full_name='injective_derivative_exchange_rpc.InjectiveDerivativeExchangeRPC.FundingRates',
    index=12,
    containing_service=None,
    input_type=_FUNDINGRATESREQUEST,
    output_type=_FUNDINGRATESRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StreamPositions',
    full_name='injective_derivative_exchange_rpc.InjectiveDerivativeExchangeRPC.StreamPositions',
    index=13,
    containing_service=None,
    input_type=_STREAMPOSITIONSREQUEST,
    output_type=_STREAMPOSITIONSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StreamOrders',
    full_name='injective_derivative_exchange_rpc.InjectiveDerivativeExchangeRPC.StreamOrders',
    index=14,
    containing_service=None,
    input_type=_STREAMORDERSREQUEST,
    output_type=_STREAMORDERSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Trades',
    full_name='injective_derivative_exchange_rpc.InjectiveDerivativeExchangeRPC.Trades',
    index=15,
    containing_service=None,
    input_type=_TRADESREQUEST,
    output_type=_TRADESRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StreamTrades',
    full_name='injective_derivative_exchange_rpc.InjectiveDerivativeExchangeRPC.StreamTrades',
    index=16,
    containing_service=None,
    input_type=_STREAMTRADESREQUEST,
    output_type=_STREAMTRADESRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SubaccountOrdersList',
    full_name='injective_derivative_exchange_rpc.InjectiveDerivativeExchangeRPC.SubaccountOrdersList',
    index=17,
    containing_service=None,
    input_type=_SUBACCOUNTORDERSLISTREQUEST,
    output_type=_SUBACCOUNTORDERSLISTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SubaccountTradesList',
    full_name='injective_derivative_exchange_rpc.InjectiveDerivativeExchangeRPC.SubaccountTradesList',
    index=18,
    containing_service=None,
    input_type=_SUBACCOUNTTRADESLISTREQUEST,
    output_type=_SUBACCOUNTTRADESLISTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='OrdersHistory',
    full_name='injective_derivative_exchange_rpc.InjectiveDerivativeExchangeRPC.OrdersHistory',
    index=19,
    containing_service=None,
    input_type=_ORDERSHISTORYREQUEST,
    output_type=_ORDERSHISTORYRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StreamOrdersHistory',
    full_name='injective_derivative_exchange_rpc.InjectiveDerivativeExchangeRPC.StreamOrdersHistory',
    index=20,
    containing_service=None,
    input_type=_STREAMORDERSHISTORYREQUEST,
    output_type=_STREAMORDERSHISTORYRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_INJECTIVEDERIVATIVEEXCHANGERPC)

DESCRIPTOR.services_by_name['InjectiveDerivativeExchangeRPC'] = _INJECTIVEDERIVATIVEEXCHANGERPC

# @@protoc_insertion_point(module_scope)
